@@ -19,30 +19,30 @@
 #include "cpu/ref_concat.hpp"
 #include "cpu/simple_concat.hpp"
 
-namespace mkldnn {
+namespace dnnl {
 namespace impl {
 namespace cpu {
 
-using cpd_create_f = mkldnn::impl::engine_t::concat_primitive_desc_create_f;
+using cpd_create_f = dnnl::impl::engine_t::concat_primitive_desc_create_f;
 
 namespace {
 #define INSTANCE(...) __VA_ARGS__::pd_t::create
 static const cpd_create_f cpu_concat_impl_list[] = {
-    INSTANCE(simple_concat_t<data_type::f32>),
-    INSTANCE(simple_concat_t<data_type::u8>),
-    INSTANCE(simple_concat_t<data_type::s8>),
-    INSTANCE(simple_concat_t<data_type::s32>),
-    INSTANCE(simple_concat_t<data_type::bf16>),
-    INSTANCE(ref_concat_t),
-    nullptr,
+        INSTANCE(simple_concat_t<data_type::f32>),
+        INSTANCE(simple_concat_t<data_type::u8>),
+        INSTANCE(simple_concat_t<data_type::s8>),
+        INSTANCE(simple_concat_t<data_type::s32>),
+        INSTANCE(simple_concat_t<data_type::bf16>),
+        INSTANCE(ref_concat_t),
+        nullptr,
 };
 #undef INSTANCE
-}
+} // namespace
 
 const cpd_create_f *cpu_engine_t::get_concat_implementation_list() const {
     return cpu_concat_impl_list;
 }
 
-}
-}
-}
+} // namespace cpu
+} // namespace impl
+} // namespace dnnl
