@@ -15,7 +15,7 @@
 *******************************************************************************/
 
 #include "c_types_map.hpp"
-#include "mkldnn_thread.hpp"
+#include "dnnl_thread.hpp"
 #include "type_helpers.hpp"
 #include "utils.hpp"
 
@@ -23,27 +23,25 @@
 
 #include "jit_avx2_1x1_convolution.hpp"
 
-namespace mkldnn {
+namespace dnnl {
 namespace impl {
 namespace cpu {
 
-using namespace mkldnn::impl::status;
-using namespace mkldnn::impl::memory_tracking::names;
-using namespace mkldnn::impl::utils;
+using namespace dnnl::impl::status;
+using namespace dnnl::impl::memory_tracking::names;
+using namespace dnnl::impl::utils;
 
 #define data_blk_off(f, n, c, h, w) \
-    ((ndims == 3) \
-    ? (f).blk_off(n, c, w) \
-    : (f).blk_off(n, c, h, w))
+    ((ndims == 3) ? (f).blk_off(n, c, w) : (f).blk_off(n, c, h, w))
 
 /* convolution forward */
 
 void jit_avx2_1x1_convolution_fwd_t::execute_forward(
         const exec_ctx_t &ctx) const {
-    auto src = CTX_IN_MEM(const data_t *, MKLDNN_ARG_SRC);
-    auto weights = CTX_IN_MEM(const data_t *, MKLDNN_ARG_WEIGHTS);
-    auto bias = CTX_IN_MEM(const data_t *, MKLDNN_ARG_BIAS);
-    auto dst = CTX_OUT_MEM(data_t *, MKLDNN_ARG_DST);
+    auto src = CTX_IN_MEM(const data_t *, DNNL_ARG_SRC);
+    auto weights = CTX_IN_MEM(const data_t *, DNNL_ARG_WEIGHTS);
+    auto bias = CTX_IN_MEM(const data_t *, DNNL_ARG_BIAS);
+    auto dst = CTX_OUT_MEM(data_t *, DNNL_ARG_DST);
 
     const memory_desc_wrapper src_d(pd()->src_md());
     const memory_desc_wrapper dst_d(pd()->dst_md());
@@ -51,7 +49,7 @@ void jit_avx2_1x1_convolution_fwd_t::execute_forward(
 
     const auto &jcp = kernel_->jcp;
     auto rtus_space = pd()->rtus_.reduce_src_
-            ? scratchpad(ctx).get<data_t>(key_conv_rtus_space)
+            ? ctx.get_scratchpad_grantor().get<data_t>(key_conv_rtus_space)
             : NULL;
 
     const int work_amount = jcp.mb * jcp.ngroups * jcp.nb_bcast;
@@ -79,14 +77,14 @@ void jit_avx2_1x1_convolution_fwd_t::execute_forward(
         const int nb_ic_blocking = jcp.nb_reduce_blocking;
         const int os_block = jcp.bcast_block;
 
-        int start{0}, end{0};
+        int start {0}, end {0};
         balance211(work_amount, nthr, ithr, start, end);
 
         int iwork = start;
         while (iwork < end) {
-            int n{0}, g{0}, osb{0};
-            nd_iterator_init(iwork, n, jcp.mb, g, jcp.ngroups, osb,
-                    jcp.nb_bcast);
+            int n {0}, g {0}, osb {0};
+            nd_iterator_init(
+                    iwork, n, jcp.mb, g, jcp.ngroups, osb, jcp.nb_bcast);
 
             int bcast_step = step(jcp.nb_bcast_blocking, jcp.nb_bcast - osb,
                     jcp.nb_bcast_blocking_max);
@@ -109,8 +107,8 @@ void jit_avx2_1x1_convolution_fwd_t::execute_forward(
                         jcp.nb_load - ocb, jcp.nb_load_blocking_max);
 
                 const int _ocb = g * nb_oc + ocb;
-                p.load_dim = this_block_size(ocb * jcp.oc_block, jcp.oc,
-                        load_step * jcp.oc_block);
+                p.load_dim = this_block_size(
+                        ocb * jcp.oc_block, jcp.oc, load_step * jcp.oc_block);
                 const size_t dst_off = data_blk_off(dst_d, n, _ocb, oh, ow);
 
                 p.output_data = &dst[dst_off];
@@ -118,24 +116,23 @@ void jit_avx2_1x1_convolution_fwd_t::execute_forward(
                 p.bias_data = &bias[_ocb * jcp.oc_block];
 
                 for (int icb = 0; icb < nb_ic; icb += nb_ic_blocking) {
-                    p.first_last_flag = 0
-                        | (icb == 0 ? FLAG_REDUCE_FIRST : 0)
-                        | (icb + nb_ic_blocking >= nb_ic
-                                ? FLAG_REDUCE_LAST : 0);
+                    p.first_last_flag = 0 | (icb == 0 ? FLAG_REDUCE_FIRST : 0)
+                            | (icb + nb_ic_blocking >= nb_ic ? FLAG_REDUCE_LAST
+                                                             : 0);
 
                     p.reduce_dim = this_block_size(icb * jcp.ic_block, jcp.ic,
                             nb_ic_blocking * jcp.ic_block);
                     rp.icb = p.reduce_dim / jcp.reduce_block;
 
                     p.load_data = &weights[pd()->with_groups()
-                        ? weights_d.blk_off(g, ocb, icb)
-                        : weights_d.blk_off(ocb, icb)];
+                                    ? weights_d.blk_off(g, ocb, icb)
+                                    : weights_d.blk_off(ocb, icb)];
 
                     const int _icb = g * nb_ic + icb;
                     if (pd()->rtus_.reduce_src_) {
                         rp.ws = rtus_space
-                            + ithr * pd()->rtus_.space_per_thread_
-                            + _icb * jcp.is * jcp.ic_block;
+                                + ithr * pd()->rtus_.space_per_thread_
+                                + _icb * jcp.is * jcp.ic_block;
 
                         if (ocb == 0) {
                             rp.src = src + data_blk_off(src_d, n, _icb, ih, iw);
@@ -144,7 +141,8 @@ void jit_avx2_1x1_convolution_fwd_t::execute_forward(
 
                         p.bcast_data = rp.ws;
                     } else
-                        p.bcast_data = src + data_blk_off(src_d, n, _icb, ih, iw);
+                        p.bcast_data
+                                = src + data_blk_off(src_d, n, _icb, ih, iw);
 
                     kernel_->jit_ker(&p);
                 }
@@ -157,7 +155,8 @@ void jit_avx2_1x1_convolution_fwd_t::execute_forward(
     };
 
     if (pd()->wants_padded_bias()) {
-        auto padded_bias = scratchpad(ctx).get<data_t>(key_conv_padded_bias);
+        auto padded_bias = ctx.get_scratchpad_grantor().get<data_t>(
+                key_conv_padded_bias);
         utils::array_copy(padded_bias, bias, jcp.oc_without_padding);
         utils::array_set(padded_bias + jcp.oc_without_padding, 0.f,
                 jcp.oc - jcp.oc_without_padding);
@@ -166,17 +165,16 @@ void jit_avx2_1x1_convolution_fwd_t::execute_forward(
 
     parallel(0, ker);
 
-    if (pd()->wants_zero_pad_dst())
-        ctx.memory(MKLDNN_ARG_DST)->zero_pad();
+    if (pd()->wants_zero_pad_dst()) ctx.memory(DNNL_ARG_DST)->zero_pad();
 }
 
 /* convolution backward wtr data */
 
 void jit_avx2_1x1_convolution_bwd_data_t::execute_backward_data(
         const exec_ctx_t &ctx) const {
-    auto diff_dst = CTX_IN_MEM(const data_t *, MKLDNN_ARG_DIFF_DST);
-    auto weights = CTX_IN_MEM(const data_t *, MKLDNN_ARG_WEIGHTS);
-    auto diff_src = CTX_OUT_MEM(data_t *, MKLDNN_ARG_DIFF_SRC);
+    auto diff_dst = CTX_IN_MEM(const data_t *, DNNL_ARG_DIFF_DST);
+    auto weights = CTX_IN_MEM(const data_t *, DNNL_ARG_WEIGHTS);
+    auto diff_src = CTX_OUT_MEM(data_t *, DNNL_ARG_DIFF_SRC);
 
     const memory_desc_wrapper diff_dst_d(pd()->diff_dst_md());
     const memory_desc_wrapper weights_d(pd()->weights_md(0));
@@ -184,7 +182,7 @@ void jit_avx2_1x1_convolution_bwd_data_t::execute_backward_data(
 
     const auto &jcp = kernel_->jcp;
     auto rtus_space = pd()->rtus_.reduce_src_
-            ? scratchpad(ctx).get<data_t>(key_conv_rtus_space)
+            ? ctx.get_scratchpad_grantor().get<data_t>(key_conv_rtus_space)
             : NULL;
 
     // TODO (Roma): remove this restriction
@@ -212,7 +210,7 @@ void jit_avx2_1x1_convolution_bwd_data_t::execute_backward_data(
         auto p = jit_1x1_conv_call_s();
         auto rp = rtus_driver_t<avx2>::call_params_t();
 
-        int start{0}, end{0};
+        int start {0}, end {0};
         balance211(work_amount, nthr, ithr, start, end);
 
         int load_step = 0;
@@ -220,23 +218,23 @@ void jit_avx2_1x1_convolution_bwd_data_t::execute_backward_data(
             load_step = step(jcp.nb_load_blocking, jcp.nb_load - icb,
                     jcp.nb_load_blocking_max);
 
-            p.load_dim = this_block_size(icb * jcp.ic_block, jcp.ic,
-                    load_step * jcp.ic_block);
+            p.load_dim = this_block_size(
+                    icb * jcp.ic_block, jcp.ic, load_step * jcp.ic_block);
             rp.icb = p.load_dim / jcp.ic_block;
 
             int bcast_step;
             for (int iwork = start; iwork < end; iwork += bcast_step) {
-                int n{0}, g{0}, osb{0};
-                nd_iterator_init(iwork, n, jcp.mb, g, jcp.ngroups, osb,
-                        jcp.nb_bcast);
+                int n {0}, g {0}, osb {0};
+                nd_iterator_init(
+                        iwork, n, jcp.mb, g, jcp.ngroups, osb, jcp.nb_bcast);
 
                 bcast_step = step(jcp.nb_bcast_blocking, jcp.nb_bcast - osb,
                         jcp.nb_bcast_blocking_max);
                 bcast_step = nstl::min(bcast_step, end - iwork);
 
                 const int os = osb * os_block;
-                p.bcast_dim = this_block_size(os, jcp.os,
-                        bcast_step * os_block);
+                p.bcast_dim
+                        = this_block_size(os, jcp.os, bcast_step * os_block);
                 rp.os = p.bcast_dim;
 
                 const int oh = os / jcp.ow;
@@ -248,8 +246,7 @@ void jit_avx2_1x1_convolution_bwd_data_t::execute_backward_data(
                 const int _icb = g * nb_ic + icb;
                 rp.src = diff_src + data_blk_off(diff_src_d, n, _icb, ih, iw);
                 if (pd()->rtus_.reduce_src_) {
-                    rp.ws = rtus_space
-                        + ithr * pd()->rtus_.space_per_thread_;
+                    rp.ws = rtus_space + ithr * pd()->rtus_.space_per_thread_;
                     p.output_data = rp.ws;
                 } else
                     p.output_data = rp.src;
@@ -257,13 +254,13 @@ void jit_avx2_1x1_convolution_bwd_data_t::execute_backward_data(
                 for (int ocb = 0; ocb < jcp.nb_reduce;
                         ocb += jcp.nb_reduce_blocking) {
                     const int _ocb = g * nb_oc + ocb;
-                    size_t diff_dst_off = data_blk_off(diff_dst_d, n, _ocb, oh,
-                        ow);
+                    size_t diff_dst_off
+                            = data_blk_off(diff_dst_d, n, _ocb, oh, ow);
                     p.bcast_data = &diff_dst[diff_dst_off];
 
                     p.load_data = &weights[pd()->with_groups()
-                        ? weights_d.blk_off(g, ocb, icb)
-                        : weights_d.blk_off(ocb, icb)];
+                                    ? weights_d.blk_off(g, ocb, icb)
+                                    : weights_d.blk_off(ocb, icb)];
 
                     p.first_last_flag = ocb == 0 ? FLAG_REDUCE_FIRST : 0;
 
@@ -273,8 +270,7 @@ void jit_avx2_1x1_convolution_bwd_data_t::execute_backward_data(
                     kernel_->jit_ker(&p);
                 }
 
-                if (pd()->rtus_.reduce_src_)
-                    rtus_driver_->ker_(&rp);
+                if (pd()->rtus_.reduce_src_) rtus_driver_->ker_(&rp);
             }
         }
     };
@@ -286,25 +282,22 @@ void jit_avx2_1x1_convolution_bwd_data_t::execute_backward_data(
 
 jit_avx2_1x1_convolution_bwd_weights_t::jit_avx2_1x1_convolution_bwd_weights_t(
         const pd_t *apd)
-    : cpu_primitive_t(apd)
-    , kernel_(nullptr)
-    , rtus_driver_(nullptr)
-{
+    : primitive_impl_t(apd), kernel_(nullptr), rtus_driver_(nullptr) {
     kernel_ = new jit_avx2_1x1_conv_kernel_f32(pd()->jcp_, *pd()->attr());
-    reducer_weights_ =
-        new cpu_reducer_2d_t<data_type::f32>(pd()->reducer_wei_conf_);
+    reducer_weights_
+            = new cpu_reducer_2d_t<data_type::f32>(pd()->reducer_wei_conf_);
     reducer_bias_ = new cpu_reducer_t<data_type::f32>(pd()->reducer_bia_conf_);
     init_rtus_driver<avx2>(this);
 }
 
 void jit_avx2_1x1_convolution_bwd_weights_t::execute_backward_weights(
         const exec_ctx_t &ctx) const {
-    auto diff_dst = CTX_IN_MEM(const data_t *, MKLDNN_ARG_DIFF_DST);
-    auto src = CTX_IN_MEM(const data_t *, MKLDNN_ARG_SRC);
-    auto diff_weights = CTX_OUT_MEM(data_t *, MKLDNN_ARG_DIFF_WEIGHTS);
-    auto diff_bias_in = CTX_OUT_MEM(data_t *, MKLDNN_ARG_DIFF_BIAS);
+    auto diff_dst = CTX_IN_MEM(const data_t *, DNNL_ARG_DIFF_DST);
+    auto src = CTX_IN_MEM(const data_t *, DNNL_ARG_SRC);
+    auto diff_weights = CTX_OUT_MEM(data_t *, DNNL_ARG_DIFF_WEIGHTS);
+    auto diff_bias_in = CTX_OUT_MEM(data_t *, DNNL_ARG_DIFF_BIAS);
 
-    auto scratchpad = this->scratchpad(ctx);
+    auto scratchpad = ctx.get_scratchpad_grantor();
 
     const memory_desc_wrapper diff_dst_d(pd()->diff_dst_md());
     const memory_desc_wrapper src_d(pd()->src_md());
@@ -317,15 +310,16 @@ void jit_avx2_1x1_convolution_bwd_weights_t::execute_backward_weights(
             : NULL;
 
     data_t *diff_bias = pd()->wants_padded_bias()
-        ? scratchpad.get<data_t>(key_conv_padded_bias) : diff_bias_in;
+            ? scratchpad.get<data_t>(key_conv_padded_bias)
+            : diff_bias_in;
 
-    auto reducer_bia_scratchpad = memory_tracking::grantor_t(scratchpad,
-            prefix_reducer_bia);
+    auto reducer_bia_scratchpad
+            = memory_tracking::grantor_t(scratchpad, prefix_reducer_bia);
     auto rb = this->reducer_bias_;
     rb->init(reducer_bia_scratchpad);
 
-    auto reducer_wei_scratchpad = memory_tracking::grantor_t(scratchpad,
-            prefix_reducer_wei);
+    auto reducer_wei_scratchpad
+            = memory_tracking::grantor_t(scratchpad, prefix_reducer_wei);
     auto rw = this->reducer_weights_;
     rw->init(reducer_wei_scratchpad);
 
@@ -355,8 +349,9 @@ void jit_avx2_1x1_convolution_bwd_weights_t::execute_backward_weights(
     };
 
     auto oc_ic_sp_loop = [=](int sp_start, int sp_end, bool first_image,
-            data_t *store_to, size_t store_to_ld, const data_t *diff_dst,
-            const data_t *src, int ithr) {
+                                 data_t *store_to, size_t store_to_ld,
+                                 const data_t *diff_dst, const data_t *src,
+                                 int ithr) {
         auto p = jit_1x1_conv_call_s();
         auto rp = rtus_driver_t<avx2>::call_params_t();
 
@@ -375,7 +370,7 @@ void jit_avx2_1x1_convolution_bwd_weights_t::execute_backward_weights(
                 rp.icb = p.bcast_dim / jcp.ic_block;
 
                 p.output_data = store_to + oc_b * store_to_ld
-                    + ic_b * jcp.ic_block * jcp.oc_block;
+                        + ic_b * jcp.ic_block * jcp.oc_block;
 
                 /* spatial reduction */
                 int sp_step = 0;
@@ -385,10 +380,11 @@ void jit_avx2_1x1_convolution_bwd_weights_t::execute_backward_weights(
                     rp.os = p.reduce_dim;
 
                     p.first_last_flag = sp == sp_start && first_image
-                        ? FLAG_REDUCE_FIRST : 0;
+                            ? FLAG_REDUCE_FIRST
+                            : 0;
 
                     p.load_data = diff_dst
-                        + (oc_b * jcp.reduce_dim + sp) * jcp.oc_block;
+                            + (oc_b * jcp.reduce_dim + sp) * jcp.oc_block;
 
                     if (pd()->rtus_.reduce_src_) {
                         const int oh = sp / jcp.ow;
@@ -399,23 +395,21 @@ void jit_avx2_1x1_convolution_bwd_weights_t::execute_backward_weights(
                         rp.iw_start = iw;
 
                         rp.ws = rtus_space
-                            + ithr * pd()->rtus_.space_per_thread_
-                            + (ic_b * jcp.is + sp) * jcp.ic_block;
+                                + ithr * pd()->rtus_.space_per_thread_
+                                + (ic_b * jcp.is + sp) * jcp.ic_block;
                         if (ndims == 3)
                             rp.src = src
-                                + iw * src_d.blocking_desc().strides[2];
+                                    + iw * src_d.blocking_desc().strides[2];
                         else
-                            rp.src = src
-                                + ih * src_d.blocking_desc().strides[2]
-                                + iw * src_d.blocking_desc().strides[3];
+                            rp.src = src + ih * src_d.blocking_desc().strides[2]
+                                    + iw * src_d.blocking_desc().strides[3];
 
-                        if (oc_b == 0)
-                            rtus_driver_->ker_(&rp);
+                        if (oc_b == 0) rtus_driver_->ker_(&rp);
 
                         p.bcast_data = rp.ws;
                     } else
                         p.bcast_data = src
-                            + (ic_b * jcp.reduce_dim + sp) * jcp.ic_block;
+                                + (ic_b * jcp.reduce_dim + sp) * jcp.ic_block;
 
                     kernel_->jit_ker(&p);
                 }
@@ -431,15 +425,15 @@ void jit_avx2_1x1_convolution_bwd_weights_t::execute_backward_weights(
 
         /* setup: independent work (oc, ic) */
         const int w_job_start = rw->balancer().ithr_job_off(ithr);
-        int g{0}, load_i{0}, bcast_i{0};
+        int g {0}, load_i {0}, bcast_i {0};
         nd_iterator_init(w_job_start, g, jcp.ngroups, load_i, load_work,
                 bcast_i, bcast_work);
 
         /* setup: reduction work (mb, sp) */
-        int mb_sp_start{0}, mb_sp_end{0};
+        int mb_sp_start {0}, mb_sp_end {0};
         balance211(mb_sp_work, rw->balancer().nthr_per_group_,
                 rw->balancer().id_in_group(ithr), mb_sp_start, mb_sp_end);
-        int img_start{0}, sp_start{0};
+        int img_start {0}, sp_start {0};
         nd_iterator_init(mb_sp_start, img_start, jcp.mb, sp_start, sp_dim);
 
         /* independent work */
@@ -455,14 +449,14 @@ void jit_avx2_1x1_convolution_bwd_weights_t::execute_backward_weights(
 
             if (rw->balancer().nthr_per_group_ == 1) {
                 const size_t off = pd()->with_groups()
-                    ? diff_weights_d.blk_off(g, oc_b, ic_b)
-                    : diff_weights_d.blk_off(oc_b, ic_b);
+                        ? diff_weights_d.blk_off(g, oc_b, ic_b)
+                        : diff_weights_d.blk_off(oc_b, ic_b);
                 store_to = &diff_weights[off];
                 store_to_ld = jcp.ic * jcp.oc_block;
             } else {
                 const size_t off = iwork * rw->balancer().job_size_;
-                store_to =
-                    rw->get_local_ptr(ithr, reducer_wei_scratchpad) + off;
+                store_to
+                        = rw->get_local_ptr(ithr, reducer_wei_scratchpad) + off;
                 store_to_ld = nb_ic_blocking * jcp.ic_block * jcp.oc_block;
             }
 
@@ -470,8 +464,7 @@ void jit_avx2_1x1_convolution_bwd_weights_t::execute_backward_weights(
             int img = img_start;
             int sp = sp_start;
             int sp_step = 0;
-            for (int mb_sp = mb_sp_start; mb_sp < mb_sp_end; mb_sp += sp_step)
-            {
+            for (int mb_sp = mb_sp_start; mb_sp < mb_sp_end; mb_sp += sp_step) {
                 sp_step = nstl::min(sp_dim - sp, mb_sp_end - mb_sp);
 
                 const bool first_image = img == img_start;
@@ -483,10 +476,12 @@ void jit_avx2_1x1_convolution_bwd_weights_t::execute_backward_weights(
                 img += 1;
             }
 
-            nd_iterator_step(g, jcp.ngroups, load_i, load_work, bcast_i,
-                             bcast_work);
+            nd_iterator_step(
+                    g, jcp.ngroups, load_i, load_work, bcast_i, bcast_work);
         }
-        rw->reduce(ithr, diff_weights, reducer_wei_scratchpad);
+
+        if (dnnl_thr_syncable())
+            rw->reduce(ithr, diff_weights, reducer_wei_scratchpad);
     };
 
     auto ker_bias = [&](int ithr, int nthr) {
@@ -498,12 +493,12 @@ void jit_avx2_1x1_convolution_bwd_weights_t::execute_backward_weights(
         if (b_njobs == 0) return;
 
         /* reduction dimension */
-        int img_start{0}, img_end{0};
+        int img_start {0}, img_end {0};
         balance211(jcp.mb, rb->balancer().nthr_per_group_,
                 rb->balancer().id_in_group(ithr), img_start, img_end);
 
         /* jobs */
-        int g_start{0}, ocb_start{0};
+        int g_start {0}, ocb_start {0};
         nd_iterator_init(b_job_start, g_start, jcp.ngroups, ocb_start, nb_oc);
 
         for (int img = img_start; img < img_end; ++img) {
@@ -512,12 +507,13 @@ void jit_avx2_1x1_convolution_bwd_weights_t::execute_backward_weights(
                 const size_t _oc = g * nb_oc + ocb;
 
                 const data_t *d_dst = &diff_dst[diff_dst_d.blk_off(img, _oc)];
-                data_t *d_bias =
-                    rb->get_local_ptr(ithr, diff_bias, reducer_bia_scratchpad)
-                    + b_job_loc * rb->balancer().job_size_;
+                data_t *d_bias = rb->get_local_ptr(ithr, diff_bias,
+                                         reducer_bia_scratchpad)
+                        + b_job_loc * rb->balancer().job_size_;
 
                 if (img == img_start)
-                    for (int o = 0; o < 8; ++o) d_bias[o] = 0.;
+                    for (int o = 0; o < 8; ++o)
+                        d_bias[o] = 0.;
 
                 for (int hw = 0; hw < jcp.oh * jcp.ow; ++hw) {
                     PRAGMA_OMP_SIMD()
@@ -529,14 +525,34 @@ void jit_avx2_1x1_convolution_bwd_weights_t::execute_backward_weights(
                 nd_iterator_step(g, jcp.ngroups, ocb, nb_oc);
             }
         }
-        rb->reduce(ithr, diff_bias, reducer_bia_scratchpad);
+
+        if (dnnl_thr_syncable())
+            rb->reduce(ithr, diff_bias, reducer_bia_scratchpad);
     };
 
+#if DNNL_THR_SYNC == 1
     parallel(0, [&](const int ithr, const int nthr) {
         ker(ithr, nthr);
-        if (pd()->with_bias())
-            ker_bias(ithr, nthr);
+        if (pd()->with_bias()) ker_bias(ithr, nthr);
     });
+#else
+    parallel(0, [&](int ithr, int nthr) { ker(ithr, nthr); });
+    parallel(0, [&](int ithr, int nthr) {
+        assert(nthr == rw->balancer().nthr_);
+        MAYBE_UNUSED(nthr);
+        if (rw->balancer().ithr_njobs(ithr) == 0) return;
+        rw->reduce_nolock(ithr, diff_weights, reducer_wei_scratchpad);
+    });
+    if (pd()->with_bias()) {
+        parallel(0, [&](int ithr, int nthr) { ker_bias(ithr, nthr); });
+        parallel(0, [&](int ithr, int nthr) {
+            assert(nthr == rb->balancer().nthr_);
+            MAYBE_UNUSED(nthr);
+            if (rb->balancer().ithr_njobs(ithr) == 0) return;
+            rb->reduce_nolock(ithr, diff_bias, reducer_bia_scratchpad);
+        });
+    }
+#endif
 
     /* TODO: put this in ker_bias */
     if (pd()->wants_padded_bias()) {
@@ -546,6 +562,6 @@ void jit_avx2_1x1_convolution_bwd_weights_t::execute_backward_weights(
     }
 }
 
-}
-}
-}
+} // namespace cpu
+} // namespace impl
+} // namespace dnnl
