@@ -15,7 +15,7 @@
 *******************************************************************************/
 
 #include "c_types_map.hpp"
-#include "mkldnn_thread.hpp"
+#include "dnnl_thread.hpp"
 #include "type_helpers.hpp"
 #include "utils.hpp"
 
@@ -25,17 +25,17 @@
 
 typedef float acc_data_t;
 
-#define IRB_LOOP(statement)                     \
+#define IRB_LOOP(statement) \
     for (int irb = 0; irb < loop_size; irb++) { \
-        statement;                              \
+        statement; \
     }
 
-namespace mkldnn {
+namespace dnnl {
 namespace impl {
 namespace cpu {
 
-using namespace mkldnn::impl::status;
-using namespace mkldnn::impl::utils;
+using namespace dnnl::impl::status;
+using namespace dnnl::impl::utils;
 using namespace data_type;
 
 using namespace Xbyak;
@@ -130,7 +130,7 @@ struct jit_avx512_common_lrn_fwd_t<d_type>::jit_avx512_common_lrn_kernel_f
 
         auto store_data = [=](const Address addr, Zmm zr, Ymm yr) {
             if (d_type == bf16) {
-                if(mayiuse(avx512_core_bf16))
+                if (mayiuse(avx512_core_bf16))
                     vcvtneps2bf16(yr, zr);
                 else
                     bf16_emu_->vcvtneps2bf16(yr, zr);
@@ -169,8 +169,7 @@ struct jit_avx512_common_lrn_fwd_t<d_type>::jit_avx512_common_lrn_kernel_f
         }
 
         loop_size = loop_size_param;
-        if (loop_size == 0)
-            return;
+        if (loop_size == 0) return;
 
         // --- loading source data to special buffer to form convenient data layout
         // for ACROSS lrn ---
@@ -361,27 +360,21 @@ status_t jit_avx512_common_lrn_fwd_t<d_type>::pd_t::init() {
     using namespace alg_kind;
 
     const memory_desc_wrapper data_d(src_md());
-    bool ok = true
-            && mayiuse(avx512_common)
-            && is_fwd()
-            && !has_zero_dim_memory()
-            && everyone_is(d_type, data_d.data_type())
-            && data_d.ndims() == 4
-            && data_d.dims()[1] % vsize == 0
+    bool ok = true && mayiuse(avx512_common)
+            && IMPLICATION(d_type == bf16, mayiuse(avx512_core)) && is_fwd()
+            && !has_zero_dim_memory() && everyone_is(d_type, data_d.data_type())
+            && data_d.ndims() == 4 && data_d.dims()[1] % vsize == 0
             && attr()->has_default_values();
-    if (!ok)
-        return unimplemented;
+    if (!ok) return unimplemented;
 
     if (desc()->prop_kind == forward_training) {
-        dims_t ws_dims = { MB(), C(), H(), 2 * W() };
-        mkldnn_memory_desc_init_by_tag(
+        dims_t ws_dims = {MB(), C(), H(), 2 * W()};
+        dnnl_memory_desc_init_by_tag(
                 &ws_md_, 4, ws_dims, d_type, format_tag::nChw16c);
     }
 
-    bool args_ok_across = true
-            && desc()->alg_kind == lrn_across_channels
-            && desc()->local_size == 5
-            && desc()->lrn_beta == 0.75
+    bool args_ok_across = true && desc()->alg_kind == lrn_across_channels
+            && desc()->local_size == 5 && desc()->lrn_beta == 0.75
             && data_d.matches_tag(format_tag::nChw16c);
 
     return args_ok_across ? success : unimplemented;
@@ -390,7 +383,7 @@ status_t jit_avx512_common_lrn_fwd_t<d_type>::pd_t::init() {
 template <data_type_t d_type>
 jit_avx512_common_lrn_fwd_t<d_type>::jit_avx512_common_lrn_fwd_t(
         const pd_t *apd)
-    : cpu_primitive_t(apd)
+    : primitive_impl_t(apd)
     , use_h_parallelism(0)
     , ker_(nullptr)
     , ker_first_(nullptr)
@@ -430,9 +423,9 @@ jit_avx512_common_lrn_fwd_t<d_type>::~jit_avx512_common_lrn_fwd_t() {
 template <data_type_t d_type>
 void jit_avx512_common_lrn_fwd_t<d_type>::execute_forward(
         const exec_ctx_t &ctx) const {
-    auto src = CTX_IN_MEM(const data_t *, MKLDNN_ARG_SRC);
-    auto dst = CTX_OUT_MEM(data_t *, MKLDNN_ARG_DST);
-    auto ws = CTX_OUT_MEM(data_t *, MKLDNN_ARG_WORKSPACE);
+    auto src = CTX_IN_MEM(const data_t *, DNNL_ARG_SRC);
+    auto dst = CTX_OUT_MEM(data_t *, DNNL_ARG_DST);
+    auto ws = CTX_OUT_MEM(data_t *, DNNL_ARG_WORKSPACE);
 
     const int N = pd()->MB();
     const int C = pd()->C();
@@ -440,13 +433,13 @@ void jit_avx512_common_lrn_fwd_t<d_type>::execute_forward(
     const int W = pd()->W();
 
     parallel(0, [&](const int ithr, const int nthr) {
-        size_t start{ 0 }, end{ 0 };
+        size_t start {0}, end {0};
         const int C16 = C / vsize;
         const size_t work_amount = use_h_parallelism ? N * C16 * H : N * C16;
 
         balance211(work_amount, nthr, ithr, start, end);
         if (use_h_parallelism) {
-            int n{ 0 }, c16{ 0 }, h{ 0 };
+            int n {0}, c16 {0}, h {0};
             nd_iterator_init(start, n, N, c16, C16, h, H);
             for (size_t iwork = start; iwork < end; ++iwork) {
                 auto offset
@@ -472,7 +465,7 @@ void jit_avx512_common_lrn_fwd_t<d_type>::execute_forward(
                 nd_iterator_step(n, N, c16, C16, h, H);
             }
         } else {
-            int n{ 0 }, c16{ 0 };
+            int n {0}, c16 {0};
             nd_iterator_init(start, n, N, c16, C16);
             for (size_t iwork = start; iwork < end; ++iwork) {
                 auto offset = n * C * H * W + c16 * H * W * vsize;
@@ -641,8 +634,7 @@ struct jit_avx512_common_lrn_bwd_t<d_type>::jit_avx512_common_lrn_kernel_f
                     mic_prefetcht2(ptr[workspace0 + (irb + prf2_offt) * vlen]));
         // -----------------------------------------------------------
 
-        if (loop_size_param == 0)
-            return;
+        if (loop_size_param == 0) return;
 
         if (!is_first && !is_single) {
             IRB_LOOP(load_data(xreg(irb, xws1_prev),
@@ -695,7 +687,8 @@ struct jit_avx512_common_lrn_bwd_t<d_type>::jit_avx512_common_lrn_kernel_f
         IRB_LOOP(vaddps(
                 zreg(irb, zdiffsrc), zreg(irb, zdiffsrc), zreg(irb, za)));
         assert(zsrc == za);
-        IRB_LOOP(load_data(zreg(irb, zsrc), EVEX_compress_addr(src, irb * vlen)));
+        IRB_LOOP(load_data(
+                zreg(irb, zsrc), EVEX_compress_addr(src, irb * vlen)));
         IRB_LOOP(vaddps(
                 zreg(irb, zdiffsrc), zreg(irb, zdiffsrc), zreg(irb, zb)));
         IRB_LOOP(vaddps(
@@ -725,8 +718,8 @@ struct jit_avx512_common_lrn_bwd_t<d_type>::jit_avx512_common_lrn_kernel_f
         L(end_store);
     }
 
-    jit_avx512_common_lrn_kernel_f(const struct nChw16c_across &J,
-            float A, float B, int use_h_parallel, void *code_ptr = nullptr,
+    jit_avx512_common_lrn_kernel_f(const struct nChw16c_across &J, float A,
+            float B, int use_h_parallel, void *code_ptr = nullptr,
             size_t code_size = 1 * Xbyak::DEFAULT_MAX_CODE_SIZE)
         : jit_generator(code_ptr, code_size)
         , nalphabeta(-2 * A * B)
@@ -826,28 +819,22 @@ status_t jit_avx512_common_lrn_bwd_t<d_type>::pd_t::init() {
     using namespace alg_kind;
 
     const memory_desc_wrapper data_d(src_md());
-    bool ok = true
-            && mayiuse(avx512_common)
-            && !is_fwd()
+    bool ok = true && mayiuse(avx512_common)
+            && IMPLICATION(d_type == bf16, mayiuse(avx512_core)) && !is_fwd()
             && utils::everyone_is(d_type, data_d.data_type())
-            && !has_zero_dim_memory()
-            && data_d.ndims() == 4
-            && data_d.dims()[1] % vsize == 0
+            && set_default_formats_common() && !has_zero_dim_memory()
+            && data_d.ndims() == 4 && data_d.dims()[1] % vsize == 0
             && attr()->has_default_values();
-    if (!ok)
-        return unimplemented;
+    if (!ok) return unimplemented;
 
-    dims_t ws_dims = { MB(), C(), H(), 2 * W() };
-    mkldnn_memory_desc_init_by_tag(
+    dims_t ws_dims = {MB(), C(), H(), 2 * W()};
+    dnnl_memory_desc_init_by_tag(
             &ws_md_, 4, ws_dims, d_type, format_tag::nChw16c);
 
-    if (!compare_ws(hint_fwd_pd_))
-        return unimplemented;
+    if (!compare_ws(hint_fwd_pd_)) return unimplemented;
 
-    bool args_ok_across = true
-            && desc()->alg_kind == lrn_across_channels
-            && desc()->local_size == 5
-            && desc()->lrn_beta == 0.75
+    bool args_ok_across = true && desc()->alg_kind == lrn_across_channels
+            && desc()->local_size == 5 && desc()->lrn_beta == 0.75
             && data_d.matches_tag(format_tag::nChw16c);
 
     return args_ok_across ? success : unimplemented;
@@ -856,7 +843,7 @@ status_t jit_avx512_common_lrn_bwd_t<d_type>::pd_t::init() {
 template <data_type_t d_type>
 jit_avx512_common_lrn_bwd_t<d_type>::jit_avx512_common_lrn_bwd_t(
         const pd_t *apd)
-    : cpu_primitive_t(apd)
+    : primitive_impl_t(apd)
     , use_h_parallelism(0)
     , ker_(nullptr)
     , ker_first_(nullptr)
@@ -893,10 +880,10 @@ jit_avx512_common_lrn_bwd_t<d_type>::~jit_avx512_common_lrn_bwd_t() {
 template <data_type_t d_type>
 void jit_avx512_common_lrn_bwd_t<d_type>::execute_backward(
         const exec_ctx_t &ctx) const {
-    auto src = CTX_IN_MEM(const data_t *, MKLDNN_ARG_SRC);
-    auto diff_dst = CTX_IN_MEM(const data_t *, MKLDNN_ARG_DIFF_DST);
-    auto ws = CTX_IN_MEM(const data_t *, MKLDNN_ARG_WORKSPACE);
-    auto diff_src = CTX_OUT_MEM(data_t *, MKLDNN_ARG_DIFF_SRC);
+    auto src = CTX_IN_MEM(const data_t *, DNNL_ARG_SRC);
+    auto diff_dst = CTX_IN_MEM(const data_t *, DNNL_ARG_DIFF_DST);
+    auto ws = CTX_IN_MEM(const data_t *, DNNL_ARG_WORKSPACE);
+    auto diff_src = CTX_OUT_MEM(data_t *, DNNL_ARG_DIFF_SRC);
 
     const int N = pd()->MB();
     const int C = pd()->C();
@@ -904,13 +891,13 @@ void jit_avx512_common_lrn_bwd_t<d_type>::execute_backward(
     const int W = pd()->W();
 
     parallel(0, [&](const int ithr, const int nthr) {
-        size_t start{ 0 }, end{ 0 };
+        size_t start {0}, end {0};
         const int C16 = C / vsize;
         const size_t work_amount = use_h_parallelism ? N * C16 * H : N * C16;
 
         balance211(work_amount, nthr, ithr, start, end);
         if (use_h_parallelism) {
-            int n{ 0 }, c16{ 0 }, h{ 0 };
+            int n {0}, c16 {0}, h {0};
             nd_iterator_init(start, n, N, h, H, c16, C16);
             for (size_t iwork = start; iwork < end; ++iwork) {
                 auto offset
@@ -937,7 +924,7 @@ void jit_avx512_common_lrn_bwd_t<d_type>::execute_backward(
                 nd_iterator_step(n, N, h, H, c16, C16);
             }
         } else {
-            int n{ 0 }, c16{ 0 };
+            int n {0}, c16 {0};
             nd_iterator_init(start, n, N, c16, C16);
             for (size_t iwork = start; iwork < end; ++iwork) {
                 auto offset = n * C * H * W + c16 * H * W * vsize;
@@ -969,6 +956,6 @@ void jit_avx512_common_lrn_bwd_t<d_type>::execute_backward(
 template struct jit_avx512_common_lrn_bwd_t<f32>;
 template struct jit_avx512_common_lrn_bwd_t<bf16>;
 
-}
-}
-}
+} // namespace cpu
+} // namespace impl
+} // namespace dnnl
