@@ -19,27 +19,27 @@
 
 #include <limits.h>
 
-#include "mkldnn_thread.hpp"
+#include "dnnl_thread.hpp"
 #include "utils.hpp"
 
 #include "cpu_isa_traits.hpp"
 #include "jit_utils/jit_utils.hpp"
 
 #if defined(_WIN32) && !defined(__GNUC__)
-#   define STRUCT_ALIGN(al, ...) __declspec(align(al)) __VA_ARGS__
+#define STRUCT_ALIGN(al, ...) __declspec(align(al)) __VA_ARGS__
 #else
-#   define STRUCT_ALIGN(al, ...) __VA_ARGS__ __attribute__((__aligned__(al)))
+#define STRUCT_ALIGN(al, ...) __VA_ARGS__ __attribute__((__aligned__(al)))
 #endif
 
 #if defined(_WIN32)
-#   define OFFSET_SHADOWSPACE 0x28
+#define OFFSET_SHADOWSPACE 0x28
 #endif
 
 #define DECLARE_CPU_JIT_AUX_FUNCTIONS(jit_name) \
     const char *name() const override { return STRINGIFY(jit_name); } \
     const char *source_file() const override { return __FILE__; }
 
-namespace mkldnn {
+namespace dnnl {
 namespace impl {
 namespace cpu {
 
@@ -81,57 +81,56 @@ static inline int float2int(float x) {
 
 #ifdef XBYAK64
 constexpr Xbyak::Operand::Code abi_save_gpr_regs[] = {
-    Xbyak::Operand::RBX, Xbyak::Operand::RBP, Xbyak::Operand::R12,
-    Xbyak::Operand::R13, Xbyak::Operand::R14, Xbyak::Operand::R15,
+        Xbyak::Operand::RBX,
+        Xbyak::Operand::RBP,
+        Xbyak::Operand::R12,
+        Xbyak::Operand::R13,
+        Xbyak::Operand::R14,
+        Xbyak::Operand::R15,
 #ifdef _WIN32
-    Xbyak::Operand::RDI, Xbyak::Operand::RSI,
+        Xbyak::Operand::RDI,
+        Xbyak::Operand::RSI,
 #endif
 };
 
 #ifdef _WIN32
 static const Xbyak::Reg64 abi_param1(Xbyak::Operand::RCX),
-             abi_param2(Xbyak::Operand::RDX),
-             abi_param3(Xbyak::Operand::R8),
-             abi_param4(Xbyak::Operand::R9),
-             abi_not_param1(Xbyak::Operand::RDI);
+        abi_param2(Xbyak::Operand::RDX), abi_param3(Xbyak::Operand::R8),
+        abi_param4(Xbyak::Operand::R9), abi_not_param1(Xbyak::Operand::RDI);
 #else
 static const Xbyak::Reg64 abi_param1(Xbyak::Operand::RDI),
-             abi_param2(Xbyak::Operand::RSI),
-             abi_param3(Xbyak::Operand::RDX),
-             abi_param4(Xbyak::Operand::RCX),
-             abi_param5(Xbyak::Operand::R8),
-             abi_param6(Xbyak::Operand::R9),
-             abi_not_param1(Xbyak::Operand::RCX);
+        abi_param2(Xbyak::Operand::RSI), abi_param3(Xbyak::Operand::RDX),
+        abi_param4(Xbyak::Operand::RCX), abi_param5(Xbyak::Operand::R8),
+        abi_param6(Xbyak::Operand::R9), abi_not_param1(Xbyak::Operand::RCX);
 #endif
 #endif
 
-inline unsigned int get_cache_size(int level, bool per_core = true){
+inline unsigned int get_cache_size(int level, bool per_core = true) {
     unsigned int l = level - 1;
     // Currently, if XByak is not able to fetch the cache topology
     // we default to 32KB of L1, 512KB of L2 and 1MB of L3 per core.
-    if (cpu.getDataCacheLevels() == 0){
+    if (cpu.getDataCacheLevels() == 0) {
         const int L1_cache_per_core = 32000;
         const int L2_cache_per_core = 512000;
         const int L3_cache_per_core = 1024000;
-        int num_cores = per_core ? 1 : mkldnn_get_max_threads();
-        switch(l){
-        case(0): return L1_cache_per_core * num_cores;
-        case(1): return L2_cache_per_core * num_cores;
-        case(2): return L3_cache_per_core * num_cores;
-        default: return 0;
+        int num_cores = per_core ? 1 : dnnl_get_max_threads();
+        switch (l) {
+            case (0): return L1_cache_per_core * num_cores;
+            case (1): return L2_cache_per_core * num_cores;
+            case (2): return L3_cache_per_core * num_cores;
+            default: return 0;
         }
     }
     if (l < cpu.getDataCacheLevels()) {
         return cpu.getDataCacheSize(l)
-            / (per_core ? cpu.getCoresSharingDataCache(l) : 1);
+                / (per_core ? cpu.getCoresSharingDataCache(l) : 1);
     } else
         return 0;
 }
 
-}
+} // namespace
 
-class jit_generator : public Xbyak::CodeGenerator
-{
+class jit_generator : public Xbyak::CodeGenerator {
 private:
     const size_t xmm_len = 16;
 #ifdef _WIN32
@@ -143,11 +142,11 @@ private:
 #endif
 
     const size_t num_abi_save_gpr_regs
-        = sizeof(abi_save_gpr_regs) / sizeof(abi_save_gpr_regs[0]);
+            = sizeof(abi_save_gpr_regs) / sizeof(abi_save_gpr_regs[0]);
 
     const size_t size_of_abi_save_regs
-        = num_abi_save_gpr_regs * rax.getBit() / 8
-        + xmm_to_preserve * xmm_len;
+            = num_abi_save_gpr_regs * rax.getBit() / 8
+            + xmm_to_preserve * xmm_len;
 
 public:
     enum {
@@ -166,15 +165,14 @@ public:
     const int EVEX_max_8b_offt = 0x200;
     const Xbyak::Reg64 reg_EVEX_max_8b_offt = rbp;
 
-    inline size_t get_size_of_abi_save_regs() {
-        return size_of_abi_save_regs;
-    }
+    inline size_t get_size_of_abi_save_regs() { return size_of_abi_save_regs; }
 
     void preamble() {
         if (xmm_to_preserve) {
             sub(rsp, xmm_to_preserve * xmm_len);
             for (size_t i = 0; i < xmm_to_preserve; ++i)
-                movdqu(ptr[rsp + i * xmm_len], Xbyak::Xmm(xmm_to_preserve_start + i));
+                movdqu(ptr[rsp + i * xmm_len],
+                        Xbyak::Xmm(xmm_to_preserve_start + i));
         }
         for (size_t i = 0; i < num_abi_save_gpr_regs; ++i)
             push(Xbyak::Reg64(abi_save_gpr_regs[i]));
@@ -184,23 +182,19 @@ public:
     }
 
     void mic_prefetcht0(Xbyak::Address a) {
-        if (mayiuse(avx512_mic))
-            prefetcht0(a);
+        if (mayiuse(avx512_mic)) prefetcht0(a);
     }
 
     void mic_prefetcht1(Xbyak::Address a) {
-        if (mayiuse(avx512_mic))
-            prefetcht1(a);
+        if (mayiuse(avx512_mic)) prefetcht1(a);
     }
 
     void mic_prefetcht2(Xbyak::Address a) {
-        if (mayiuse(avx512_mic))
-            prefetcht2(a);
+        if (mayiuse(avx512_mic)) prefetcht2(a);
     }
 
     void uni_vzeroupper() {
-        if (mayiuse(avx) && !mayiuse(avx512_mic))
-            vzeroupper();
+        if (mayiuse(avx) && !mayiuse(avx512_mic)) vzeroupper();
     }
 
     void postamble() {
@@ -208,21 +202,21 @@ public:
             pop(Xbyak::Reg64(abi_save_gpr_regs[num_abi_save_gpr_regs - 1 - i]));
         if (xmm_to_preserve) {
             for (size_t i = 0; i < xmm_to_preserve; ++i)
-                movdqu(Xbyak::Xmm(xmm_to_preserve_start + i), ptr[rsp + i * xmm_len]);
+                movdqu(Xbyak::Xmm(xmm_to_preserve_start + i),
+                        ptr[rsp + i * xmm_len]);
             add(rsp, xmm_to_preserve * xmm_len);
         }
         uni_vzeroupper();
         ret();
     }
 
-    template<typename T>
-    Xbyak::Address EVEX_compress_addr(Xbyak::Reg64 base,
-            T raw_offt, bool bcast = false)
-    {
-        using Xbyak::Zmm;
-        using Xbyak::Reg64;
+    template <typename T>
+    Xbyak::Address EVEX_compress_addr(
+            Xbyak::Reg64 base, T raw_offt, bool bcast = false) {
         using Xbyak::Address;
+        using Xbyak::Reg64;
         using Xbyak::RegExp;
+        using Xbyak::Zmm;
 
         assert(raw_offt <= INT_MAX);
         auto offt = static_cast<int>(raw_offt);
@@ -232,23 +226,23 @@ public:
         if (EVEX_max_8b_offt <= offt && offt < 3 * EVEX_max_8b_offt) {
             offt = offt - 2 * EVEX_max_8b_offt;
             scale = 1;
-        } else if (3 * EVEX_max_8b_offt <= offt && offt < 5 * EVEX_max_8b_offt) {
+        } else if (3 * EVEX_max_8b_offt <= offt
+                && offt < 5 * EVEX_max_8b_offt) {
             offt = offt - 4 * EVEX_max_8b_offt;
             scale = 2;
         }
 
         auto re = RegExp() + base + offt;
-        if (scale)
-            re = re + reg_EVEX_max_8b_offt * scale;
+        if (scale) re = re + reg_EVEX_max_8b_offt * scale;
 
         if (bcast)
-            return zword_b [re];
+            return zword_b[re];
         else
-            return zword [re];
+            return zword[re];
     }
 
     Xbyak::Address make_safe_addr(const Xbyak::Reg64 &reg_out, size_t offt,
-        const Xbyak::Reg64 &tmp_reg, bool bcast = false) {
+            const Xbyak::Reg64 &tmp_reg, bool bcast = false) {
         if (offt > INT_MAX) {
             mov(tmp_reg, offt);
             return bcast ? ptr_b[reg_out + tmp_reg] : ptr[reg_out + tmp_reg];
@@ -258,7 +252,7 @@ public:
     }
 
     Xbyak::Address EVEX_compress_addr_safe(const Xbyak::Reg64 &base,
-        size_t raw_offt, const Xbyak::Reg64 &reg_offt, bool bcast = false) {
+            size_t raw_offt, const Xbyak::Reg64 &reg_offt, bool bcast = false) {
         if (raw_offt > INT_MAX) {
             return make_safe_addr(base, raw_offt, reg_offt, bcast);
         } else {
@@ -267,7 +261,7 @@ public:
     }
 
     void safe_add(const Xbyak::Reg64 &base, size_t raw_offt,
-        const Xbyak::Reg64 &reg_offt) {
+            const Xbyak::Reg64 &reg_offt) {
         if (raw_offt > INT_MAX) {
             mov(reg_offt, raw_offt);
             add(base, reg_offt);
@@ -277,7 +271,7 @@ public:
     }
 
     void safe_sub(const Xbyak::Reg64 &base, size_t raw_offt,
-        const Xbyak::Reg64 &reg_offt) {
+            const Xbyak::Reg64 &reg_offt) {
         if (raw_offt > INT_MAX) {
             mov(reg_offt, raw_offt);
             sub(base, reg_offt);
@@ -288,7 +282,7 @@ public:
 
     // Disallow char-based labels completely
     void L(const char *label) = delete;
-    void L(Xbyak::Label& label) { Xbyak::CodeGenerator::L(label); }
+    void L(Xbyak::Label &label) { Xbyak::CodeGenerator::L(label); }
 
     void L_aligned(Xbyak::Label &label, int alignment = 16) {
         align(alignment);
@@ -296,12 +290,12 @@ public:
     }
 
     void uni_vpxor(const Xbyak::Xmm &x1, const Xbyak::Xmm &x2,
-                   const Xbyak::Operand &op) {
+            const Xbyak::Operand &op) {
         assert(x1.getIdx() == x2.getIdx());
         pxor(x2, op);
     }
     void uni_vpxor(const Xbyak::Ymm &x1, const Xbyak::Ymm &x2,
-                   const Xbyak::Operand &op) {
+            const Xbyak::Operand &op) {
         if (mayiuse(avx2)) {
             vpxor(x1, x2, op);
         } else {
@@ -309,33 +303,33 @@ public:
         }
     }
     void uni_vpxor(const Xbyak::Zmm &x1, const Xbyak::Zmm &x2,
-                   const Xbyak::Operand &op) {
+            const Xbyak::Operand &op) {
         vpxord(x1, x2, op);
     }
 
-    void uni_vmovss(const Xbyak::Address& addr, const Xbyak::Xmm &x) {
+    void uni_vmovss(const Xbyak::Address &addr, const Xbyak::Xmm &x) {
         movss(addr, x);
     }
-    void uni_vmovss(const Xbyak::Address& addr, const Xbyak::Ymm &x) {
+    void uni_vmovss(const Xbyak::Address &addr, const Xbyak::Ymm &x) {
         vmovss(addr, Xbyak::Xmm(x.getIdx()));
     }
-    void uni_vmovss(const Xbyak::Xmm &x, const Xbyak::Address& addr) {
+    void uni_vmovss(const Xbyak::Xmm &x, const Xbyak::Address &addr) {
         movss(x, addr);
     }
-    void uni_vmovss(const Xbyak::Ymm &x, const Xbyak::Address& addr) {
+    void uni_vmovss(const Xbyak::Ymm &x, const Xbyak::Address &addr) {
         vmovss(Xbyak::Xmm(x.getIdx()), addr);
     }
 
-    void uni_vmovsd(const Xbyak::Address& addr, const Xbyak::Xmm &x) {
+    void uni_vmovsd(const Xbyak::Address &addr, const Xbyak::Xmm &x) {
         movsd(addr, x);
     }
-    void uni_vmovsd(const Xbyak::Address& addr, const Xbyak::Ymm &x) {
+    void uni_vmovsd(const Xbyak::Address &addr, const Xbyak::Ymm &x) {
         vmovsd(addr, x);
     }
-    void uni_vmovsd(const Xbyak::Xmm &x, const Xbyak::Address& addr) {
+    void uni_vmovsd(const Xbyak::Xmm &x, const Xbyak::Address &addr) {
         movsd(x, addr);
     }
-    void uni_vmovsd(const Xbyak::Ymm &x, const Xbyak::Address& addr) {
+    void uni_vmovsd(const Xbyak::Ymm &x, const Xbyak::Address &addr) {
         vmovsd(x, addr);
     }
 
@@ -434,163 +428,159 @@ public:
     }
 
     void uni_vdivps(const Xbyak::Xmm &x, const Xbyak::Operand &op1,
-                    const Xbyak::Operand &op2 = Xbyak::Operand()) {
+            const Xbyak::Operand &op2 = Xbyak::Operand()) {
         assert(x.getIdx() == op1.getIdx());
         divps(x, op2);
     }
     void uni_vdivps(const Xbyak::Ymm &x, const Xbyak::Operand &op1,
-                    const Xbyak::Operand &op2 = Xbyak::Operand()) {
+            const Xbyak::Operand &op2 = Xbyak::Operand()) {
         vdivps(x, op1, op2);
     }
 
     void uni_vdivps(const Xbyak::Xmm &x, const Xbyak::Operand &op1,
-                    const Xbyak::Operand &op2, const Xbyak::Xmm &buf) {
+            const Xbyak::Operand &op2, const Xbyak::Xmm &buf) {
         movups(buf, op1);
         divps(buf, op2);
-        if (x.getIdx() != buf.getIdx()) {
-            movups(x, buf);
-        }
+        if (x.getIdx() != buf.getIdx()) { movups(x, buf); }
     }
 
     void uni_vdivps(const Xbyak::Ymm &x, const Xbyak::Operand &op1,
-                    const Xbyak::Operand &op2, const Xbyak::Ymm &buf) {
+            const Xbyak::Operand &op2, const Xbyak::Ymm &buf) {
         vdivps(x, op1, op2);
     }
 
     void uni_vaddps(const Xbyak::Xmm &x, const Xbyak::Operand &op1,
-                    const Xbyak::Operand &op2 = Xbyak::Operand()) {
+            const Xbyak::Operand &op2 = Xbyak::Operand()) {
         assert(x.getIdx() == op1.getIdx());
         addps(x, op2);
     }
     void uni_vaddps(const Xbyak::Ymm &x, const Xbyak::Operand &op1,
-                    const Xbyak::Operand &op2 = Xbyak::Operand()) {
+            const Xbyak::Operand &op2 = Xbyak::Operand()) {
         vaddps(x, op1, op2);
     }
     void uni_vaddss(const Xbyak::Xmm &x, const Xbyak::Operand &op1,
-                    const Xbyak::Operand &op2 = Xbyak::Operand()) {
+            const Xbyak::Operand &op2 = Xbyak::Operand()) {
         assert(x.getIdx() == op1.getIdx());
         addss(x, op2);
     }
     void uni_vaddss(const Xbyak::Ymm &x, const Xbyak::Operand &op1,
-                    const Xbyak::Operand &op2 = Xbyak::Operand()) {
+            const Xbyak::Operand &op2 = Xbyak::Operand()) {
         vaddss(x, op1, op2);
     }
 
-    void uni_vpsignd(const Xbyak::Xmm& x1, const Xbyak::Xmm& x2,
-                     const Xbyak::Operand& op) {
+    void uni_vpsignd(const Xbyak::Xmm &x1, const Xbyak::Xmm &x2,
+            const Xbyak::Operand &op) {
         assert(x1.getIdx() == x2.getIdx());
         psignd(x1, op);
     }
-    void uni_vpsignd(const Xbyak::Ymm& x1, const Xbyak::Ymm& x2,
-                     const Xbyak::Operand& op) {
+    void uni_vpsignd(const Xbyak::Ymm &x1, const Xbyak::Ymm &x2,
+            const Xbyak::Operand &op) {
         vpsignd(x1, x2, op);
     }
 
     void uni_vsubss(const Xbyak::Xmm &x, const Xbyak::Operand &op1,
-                    const Xbyak::Operand &op2 = Xbyak::Operand()) {
+            const Xbyak::Operand &op2 = Xbyak::Operand()) {
         assert(x.getIdx() == op1.getIdx());
         subps(x, op2);
     }
     void uni_vsubss(const Xbyak::Ymm &x, const Xbyak::Operand &op1,
-                    const Xbyak::Operand &op2 = Xbyak::Operand()) {
+            const Xbyak::Operand &op2 = Xbyak::Operand()) {
         vsubss(x, Xbyak::Xmm(op1.getIdx()), Xbyak::Xmm(op2.getIdx()));
     }
 
     void uni_vsubps(const Xbyak::Xmm &x, const Xbyak::Operand &op1,
-                    const Xbyak::Operand &op2 = Xbyak::Operand()) {
+            const Xbyak::Operand &op2 = Xbyak::Operand()) {
         assert(x.getIdx() == op1.getIdx());
         subps(x, op2);
     }
     void uni_vsubps(const Xbyak::Ymm &x, const Xbyak::Operand &op1,
-                    const Xbyak::Operand &op2 = Xbyak::Operand()) {
+            const Xbyak::Operand &op2 = Xbyak::Operand()) {
         vsubps(x, op1, op2);
     }
 
     void uni_vsubps(const Xbyak::Xmm &x, const Xbyak::Operand &op1,
-                    const Xbyak::Operand &op2, const Xbyak::Xmm &buf) {
+            const Xbyak::Operand &op2, const Xbyak::Xmm &buf) {
         movups(buf, op1);
         subps(buf, op2);
-        if (x.getIdx() != buf.getIdx()) {
-            movups(x, buf);
-        }
+        if (x.getIdx() != buf.getIdx()) { movups(x, buf); }
     }
 
     void uni_vsubps(const Xbyak::Ymm &x, const Xbyak::Operand &op1,
-                    const Xbyak::Operand &op2, const Xbyak::Ymm &buf) {
+            const Xbyak::Operand &op2, const Xbyak::Ymm &buf) {
         vsubps(x, op1, op2);
     }
 
     void uni_vmulps(const Xbyak::Xmm &x, const Xbyak::Operand &op1,
-                    const Xbyak::Operand &op2 = Xbyak::Operand()) {
+            const Xbyak::Operand &op2 = Xbyak::Operand()) {
         assert(x.getIdx() == op1.getIdx());
         mulps(x, op2);
     }
     void uni_vmulps(const Xbyak::Ymm &x, const Xbyak::Operand &op1,
-                    const Xbyak::Operand &op2 = Xbyak::Operand()) {
+            const Xbyak::Operand &op2 = Xbyak::Operand()) {
         vmulps(x, op1, op2);
     }
 
     void uni_vmulss(const Xbyak::Xmm &x, const Xbyak::Operand &op1,
-                    const Xbyak::Operand &op2 = Xbyak::Operand()) {
+            const Xbyak::Operand &op2 = Xbyak::Operand()) {
         assert(x.getIdx() == op1.getIdx());
         mulss(x, op2);
     }
     void uni_vmulss(const Xbyak::Ymm &x, const Xbyak::Operand &op1,
-                    const Xbyak::Address &op2) {
+            const Xbyak::Address &op2) {
         vmulss(x, Xbyak::Xmm(op1.getIdx()), op2);
     }
     void uni_vmulss(const Xbyak::Ymm &x, const Xbyak::Operand &op1,
-                    const Xbyak::Ymm &op2) {
+            const Xbyak::Ymm &op2) {
         vmulss(x, Xbyak::Xmm(op1.getIdx()), Xbyak::Xmm(op2.getIdx()));
     }
 
     void uni_vfmadd213ps(const Xbyak::Xmm &x1, const Xbyak::Xmm &x2,
-                         const Xbyak::Operand &op) {
+            const Xbyak::Operand &op) {
         mulps(x1, x2);
         addps(x1, op);
     }
     void uni_vfmadd213ps(const Xbyak::Ymm &x1, const Xbyak::Ymm &x2,
-                         const Xbyak::Operand &op) {
+            const Xbyak::Operand &op) {
         vfmadd213ps(x1, x2, op);
     }
 
     void uni_vfmadd213ss(const Xbyak::Xmm &x1, const Xbyak::Xmm &x2,
-                         const Xbyak::Operand &op) {
+            const Xbyak::Operand &op) {
         mulss(x1, x2);
         addss(x1, op);
     }
     void uni_vfmadd213ss(const Xbyak::Ymm &x1, const Xbyak::Ymm &x2,
-                         const Xbyak::Operand &op) {
+            const Xbyak::Operand &op) {
         vfmadd213ss(x1, x2, op);
     }
 
     void uni_vfmadd231ps(const Xbyak::Xmm &x1, const Xbyak::Xmm &x2,
-                         const Xbyak::Operand &op) {
+            const Xbyak::Operand &op) {
         mulps(x2, op);
         addps(x1, x2);
     }
     void uni_vfmadd231ps(const Xbyak::Ymm &x1, const Xbyak::Ymm &x2,
-                         const Xbyak::Operand &op) {
+            const Xbyak::Operand &op) {
         vfmadd231ps(x1, x2, op);
     }
     void uni_vfmadd231ss(const Xbyak::Xmm &x1, const Xbyak::Xmm &x2,
-                         const Xbyak::Operand &op) {
+            const Xbyak::Operand &op) {
         mulss(x2, op);
         addss(x1, x2);
     }
     void uni_vfmadd231ss(const Xbyak::Ymm &x1, const Xbyak::Ymm &x2,
-                         const Xbyak::Operand &op) {
+            const Xbyak::Operand &op) {
         vfmadd231ss(Xbyak::Xmm(x1.getIdx()), Xbyak::Xmm(x2.getIdx()), op);
     }
 
     void uni_vfnmadd231ps(const Xbyak::Xmm &x1, const Xbyak::Xmm &x2,
-                           const Xbyak::Operand &op) {
+            const Xbyak::Operand &op) {
         mulps(x2, op);
         subps(x1, x2);
     }
 
     void uni_vfnmadd231ps(const Xbyak::Ymm &x1, const Xbyak::Ymm &x2,
-                           const Xbyak::Operand &op) {
+            const Xbyak::Operand &op) {
         vfnmadd231ps(x1, x2, op);
     }
 
@@ -602,22 +592,22 @@ public:
     }
 
     void uni_vpaddd(const Xbyak::Xmm &x1, const Xbyak::Xmm &x2,
-                    const Xbyak::Operand &op) {
+            const Xbyak::Operand &op) {
         assert(x1.getIdx() == x2.getIdx());
         paddd(x2, op);
     }
     void uni_vpaddd(const Xbyak::Ymm &x1, const Xbyak::Xmm &x2,
-                    const Xbyak::Operand &op) {
+            const Xbyak::Operand &op) {
         vpaddd(x1, x2, op);
     }
 
     void uni_vandps(const Xbyak::Xmm &x1, const Xbyak::Xmm &x2,
-                    const Xbyak::Operand &op = Xbyak::Operand()) {
+            const Xbyak::Operand &op = Xbyak::Operand()) {
         assert(x1.getIdx() == x2.getIdx());
         andps(x1, op);
     }
     void uni_vandps(const Xbyak::Ymm &x1, const Xbyak::Ymm &x2,
-                    const Xbyak::Operand &op = Xbyak::Operand()) {
+            const Xbyak::Operand &op = Xbyak::Operand()) {
         if (!mayiuse(avx512_common) || x1.getBit() < 512)
             vandps(x1, x2, op);
         else
@@ -625,77 +615,77 @@ public:
     }
 
     void uni_vorps(const Xbyak::Xmm &x1, const Xbyak::Xmm &x2,
-                    const Xbyak::Operand &op = Xbyak::Operand()) {
+            const Xbyak::Operand &op = Xbyak::Operand()) {
         assert(x1.getIdx() == x2.getIdx());
         orps(x1, op);
     }
     void uni_vorps(const Xbyak::Ymm &x1, const Xbyak::Ymm &x2,
-                    const Xbyak::Operand &op = Xbyak::Operand()) {
+            const Xbyak::Operand &op = Xbyak::Operand()) {
         if (!mayiuse(avx512_common) || x1.getBit() < 512)
             vorps(x1, x2, op);
         else
             vpord(x1, x2, op);
     }
 
-    void uni_vpslld(const Xbyak::Xmm &x, const Xbyak::Operand &op,
-                    const int imm) {
+    void uni_vpslld(
+            const Xbyak::Xmm &x, const Xbyak::Operand &op, const int imm) {
         assert(x.getIdx() == op.getIdx());
         pslld(x, imm);
     }
-    void uni_vpslld(const Xbyak::Ymm &x, const Xbyak::Operand &op,
-                    const int imm) {
+    void uni_vpslld(
+            const Xbyak::Ymm &x, const Xbyak::Operand &op, const int imm) {
         vpslld(x, op, imm);
     }
 
-    void uni_vpsrld(const Xbyak::Xmm &x, const Xbyak::Operand &op,
-                    const int imm) {
+    void uni_vpsrld(
+            const Xbyak::Xmm &x, const Xbyak::Operand &op, const int imm) {
         assert(x.getIdx() == op.getIdx());
         psrld(x, imm);
     }
-    void uni_vpsrld(const Xbyak::Ymm &x, const Xbyak::Operand &op,
-                    const int imm) {
+    void uni_vpsrld(
+            const Xbyak::Ymm &x, const Xbyak::Operand &op, const int imm) {
         vpsrld(x, op, imm);
     }
 
     void uni_vmaxps(const Xbyak::Xmm &x, const Xbyak::Operand &op1,
-                    const Xbyak::Operand &op2 = Xbyak::Operand()) {
+            const Xbyak::Operand &op2 = Xbyak::Operand()) {
         assert(x.getIdx() == op1.getIdx());
         maxps(x, op2);
     }
     void uni_vmaxps(const Xbyak::Ymm &x, const Xbyak::Operand &op1,
-                    const Xbyak::Operand &op2 = Xbyak::Operand()) {
+            const Xbyak::Operand &op2 = Xbyak::Operand()) {
         vmaxps(x, op1, op2);
     }
 
     void uni_vminps(const Xbyak::Xmm &x, const Xbyak::Operand &op1,
-                    const Xbyak::Operand &op2 = Xbyak::Operand()) {
+            const Xbyak::Operand &op2 = Xbyak::Operand()) {
         assert(x.getIdx() == op1.getIdx());
         minps(x, op2);
     }
     void uni_vminps(const Xbyak::Ymm &x, const Xbyak::Operand &op1,
-                    const Xbyak::Operand &op2 = Xbyak::Operand()) {
+            const Xbyak::Operand &op2 = Xbyak::Operand()) {
         vminps(x, op1, op2);
     }
 
     void uni_vcmpgtps(const Xbyak::Xmm &x1, const Xbyak::Xmm &x2,
-                      const Xbyak::Operand &op) {
+            const Xbyak::Operand &op) {
         assert(x1.getIdx() == x2.getIdx());
         cmpps(x1, op, _cmp_nle_us);
     }
 
     void uni_vcmpgtps(const Xbyak::Ymm &x1, const Xbyak::Ymm &x2,
-                      const Xbyak::Operand &op) {
+            const Xbyak::Operand &op) {
         vcmpgtps(x1, x2, op);
     }
 
     void uni_vcmpgeps(const Xbyak::Xmm &x1, const Xbyak::Xmm &x2,
-                      const Xbyak::Operand &op) {
+            const Xbyak::Operand &op) {
         assert(x1.getIdx() == x2.getIdx());
         cmpps(x1, op, _cmp_nlt_us);
     }
 
     void uni_vcmpgeps(const Xbyak::Ymm &x1, const Xbyak::Ymm &x2,
-                      const Xbyak::Operand &op) {
+            const Xbyak::Operand &op) {
         vcmpps(x1, x2, op, _cmp_nlt_us);
     }
 
@@ -709,26 +699,26 @@ public:
     }
 
     void uni_vblendvps(const Xbyak::Xmm &x1, const Xbyak::Xmm &x2,
-                       const Xbyak::Operand &op, const Xbyak::Xmm &msk) {
+            const Xbyak::Operand &op, const Xbyak::Xmm &msk) {
         assert(x1.getIdx() == x2.getIdx());
         assert(msk.getIdx() == 0);
         blendvps(x1, op);
     }
     void uni_vblendvps(const Xbyak::Ymm &x1, const Xbyak::Ymm &x2,
-                       const Xbyak::Operand &op, const Xbyak::Ymm &msk) {
+            const Xbyak::Operand &op, const Xbyak::Ymm &msk) {
         vblendvps(x1, x2, op, msk);
     }
 
-    void uni_vroundps(const Xbyak::Xmm &x, const Xbyak::Operand &op,
-                      const int imm) {
+    void uni_vroundps(
+            const Xbyak::Xmm &x, const Xbyak::Operand &op, const int imm) {
         roundps(x, op, imm);
     }
-    void uni_vroundps(const Xbyak::Ymm &x, const Xbyak::Operand &op,
-                      const int imm) {
+    void uni_vroundps(
+            const Xbyak::Ymm &x, const Xbyak::Operand &op, const int imm) {
         vroundps(x, op, imm);
     }
-    void uni_vroundps(const Xbyak::Zmm &x, const Xbyak::Operand &op,
-                      const int imm) {
+    void uni_vroundps(
+            const Xbyak::Zmm &x, const Xbyak::Operand &op, const int imm) {
         vrndscaleps(x, op, imm & 0x3);
     }
 
@@ -753,25 +743,28 @@ public:
         vmovmskps(x1, x2);
     }
 
-    void uni_vpackssdw(const Xbyak::Xmm &x1, const Xbyak::Xmm &x2, const Xbyak::Operand &op){
+    void uni_vpackssdw(const Xbyak::Xmm &x1, const Xbyak::Xmm &x2,
+            const Xbyak::Operand &op) {
         assert(x1.getIdx() == x1.getIdx());
         packssdw(x1, op);
     }
-    void uni_vpackssdw(const Xbyak::Ymm &x1, const Xbyak::Ymm &x2, const Xbyak::Operand &op){
+    void uni_vpackssdw(const Xbyak::Ymm &x1, const Xbyak::Ymm &x2,
+            const Xbyak::Operand &op) {
         vpackssdw(x1, x2, op);
     }
 
-    void uni_vpackuswb(const Xbyak::Xmm &x1, const Xbyak::Xmm &x2, const Xbyak::Operand &op){
+    void uni_vpackuswb(const Xbyak::Xmm &x1, const Xbyak::Xmm &x2,
+            const Xbyak::Operand &op) {
         assert(x1.getIdx() == x1.getIdx());
         packuswb(x1, op);
     }
-    void uni_vpackuswb(const Xbyak::Ymm &x1, const Xbyak::Ymm &x2, const Xbyak::Operand &op){
+    void uni_vpackuswb(const Xbyak::Ymm &x1, const Xbyak::Ymm &x2,
+            const Xbyak::Operand &op) {
         vpackuswb(x1, x2, op);
     }
 
-
-    void mul_by_const(const Xbyak::Reg &out,
-            const Xbyak::Reg64 &tmp, int value) {
+    void mul_by_const(
+            const Xbyak::Reg &out, const Xbyak::Reg64 &tmp, int value) {
         // Generates a shift + add sequence for multiplicating contents of the
         // out register by a known JIT-time value. Clobbers the tmp register.
         //
@@ -803,15 +796,11 @@ public:
         mov(out, tmp);
     }
 
-    MKLDNN_DISALLOW_COPY_AND_ASSIGN(jit_generator);
+    DNNL_DISALLOW_COPY_AND_ASSIGN(jit_generator);
 
 public:
-    jit_generator(
-        void *code_ptr = nullptr,
-        size_t code_size = 256 * 1024
-        ) : Xbyak::CodeGenerator(code_size, code_ptr)
-    {
-    }
+    jit_generator(void *code_ptr = nullptr, size_t code_size = 256 * 1024)
+        : Xbyak::CodeGenerator(code_size, code_ptr) {}
     virtual ~jit_generator() {}
 
     virtual const char *name() const = 0;
@@ -824,13 +813,14 @@ public:
         return code;
     }
 
-    template<typename F> const F getCode() {
+    template <typename F>
+    const F getCode() {
         return (const F)getCode();
     }
 };
 
-}
-}
-}
+} // namespace cpu
+} // namespace impl
+} // namespace dnnl
 
 #endif
