@@ -17,8 +17,8 @@
 #include <assert.h>
 
 #include "c_types_map.hpp"
+#include "dnnl_thread.hpp"
 #include "math_utils.hpp"
-#include "mkldnn_thread.hpp"
 #include "nstl.hpp"
 #include "type_helpers.hpp"
 #include "utils.hpp"
@@ -28,7 +28,7 @@
 #include "jit_uni_eltwise.hpp"
 #include "jit_uni_softmax.hpp"
 
-namespace mkldnn {
+namespace dnnl {
 namespace impl {
 namespace cpu {
 
@@ -39,7 +39,7 @@ typedef float data_t;
 using namespace Xbyak;
 
 template <cpu_isa_t isa>
-struct jit_softmax_t: public jit_generator {
+struct jit_softmax_t : public jit_generator {
     struct call_params_t {
         // keep all sizes at 8 bytes -- jit code expects this
         const data_t *src, *dst;
@@ -49,8 +49,8 @@ struct jit_softmax_t: public jit_generator {
 
     // cpu specific part
     using Vmm = typename cpu_isa_traits<isa>::Vmm;
-    const AddressFrame &vmmword = (isa == sse41) ? xword :
-                                  (isa == avx2) ? yword : zword;
+    const AddressFrame &vmmword
+            = (isa == sse41) ? xword : (isa == avx2) ? yword : zword;
     const int vlen = cpu_isa_traits<isa>::vlen;
 
     const softmax_pd_t *sdesc_;
@@ -81,20 +81,29 @@ struct jit_softmax_t: public jit_generator {
     Vmm vsum = Vmm(isa == avx512_common ? 30 : 14);
     Vmm vmax = Vmm(isa == avx512_common ? 31 : 15);
 
-    size_t simd_w_;
+    size_t simd_w_ = vlen / sizeof(data_t);
+    size_t unroll_regs_ = 4;
+
     size_t axis_simd_full_;
     size_t axis_simd_tail_;
-    size_t unroll_regs_;
     size_t n_loops_;
     size_t loop_tail_;
+    size_t axis_stride_;
 
     void compute_predefined_variables() {
-        simd_w_ = vlen / sizeof(data_t);
         axis_simd_full_ = sdesc_->axis_size() / simd_w_;
         axis_simd_tail_ = sdesc_->axis_size() % simd_w_;
-        unroll_regs_ = 4;
         n_loops_ = axis_simd_full_ / unroll_regs_;
         loop_tail_ = axis_simd_full_ - n_loops_ * unroll_regs_;
+        axis_stride_ = compute_axis_stride();
+    }
+
+    size_t compute_axis_stride() {
+        const memory_desc_wrapper data_d(sdesc_->src_md());
+        const auto &bd = data_d.blocking_desc();
+
+        if (bd.inner_nblks) return sizeof(data_t) * bd.strides[sdesc_->axis()];
+        return vlen;
     }
 
     void load_common_params() {
@@ -105,11 +114,11 @@ struct jit_softmax_t: public jit_generator {
         movq(xneg_flt_max, reg_tmp);
         uni_vbroadcastss(vneg_flt_max, xneg_flt_max);
 
-#       define PARAM_OFF(x) offsetof(call_params_t, x)
+#define PARAM_OFF(x) offsetof(call_params_t, x)
         mov(reg_soff_max, ptr[reg_param + PARAM_OFF(soff_max)]);
         mov(reg_src, ptr[reg_param + PARAM_OFF(src)]);
         mov(reg_dst, ptr[reg_param + PARAM_OFF(dst)]);
-#       undef PARAM_OFF
+#undef PARAM_OFF
     }
 
     void prepare_tail_mask_sse41() {
@@ -127,8 +136,9 @@ struct jit_softmax_t: public jit_generator {
                 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
                 0xffffffff, 0, 0, 0, 0, 0, 0, 0, 0};
 
-        mov(reg_tmp, reinterpret_cast<size_t>(
-                    &mask_f32[8 - axis_simd_tail_ % simd_w_]));
+        mov(reg_tmp,
+                reinterpret_cast<size_t>(
+                        &mask_f32[8 - axis_simd_tail_ % simd_w_]));
         vmovups(vtail_mask, ptr[reg_tmp]);
     }
 
@@ -174,8 +184,10 @@ struct jit_softmax_t: public jit_generator {
     enum class op_t : unsigned { max, sum };
 
     void perform_op(Vmm v, Vmm vtmp, op_t op) {
-        if (op == op_t::max) uni_vmaxps(v, v, vtmp);
-        else if (op == op_t::sum) uni_vaddps(v, v, vtmp);
+        if (op == op_t::max)
+            uni_vmaxps(v, v, vtmp);
+        else if (op == op_t::sum)
+            uni_vaddps(v, v, vtmp);
     }
 
     void get_horizontal_op(Vmm &v, Vmm &vtmp, op_t op) {
@@ -198,30 +210,31 @@ struct jit_softmax_t: public jit_generator {
         Label main_loop, tail_loop, tail_axis;
 
         mov(reg_rsoff, reg_soff_max); // reverse soff to dispatch between labels
-        xor_(reg_soff, reg_soff);     // soff to get addr of src/dst
-        L(main_loop); {
+        xor_(reg_soff, reg_soff); // soff to get addr of src/dst
+        L(main_loop);
+        {
             if (n_loops_) {
-                cmp(reg_rsoff, unroll_regs_ * vlen);
+                cmp(reg_rsoff, unroll_regs_ * axis_stride_);
                 jl(tail_loop, T_NEAR);
 
                 body(unroll_regs_);
-                sub(reg_rsoff, unroll_regs_ * vlen);
-                add(reg_soff, unroll_regs_ * vlen);
+                sub(reg_rsoff, unroll_regs_ * axis_stride_);
+                add(reg_soff, unroll_regs_ * axis_stride_);
                 jmp(main_loop);
             }
         }
 
-        L(tail_loop); {
+        L(tail_loop);
+        {
             if (loop_tail_) {
                 body(loop_tail_);
-                add(reg_soff, loop_tail_ * vlen);
+                add(reg_soff, loop_tail_ * axis_stride_);
             }
         }
 
-        L(tail_axis); {
-            if (axis_simd_tail_) {
-                body(1, true);
-            }
+        L(tail_axis);
+        {
+            if (axis_simd_tail_) { body(1, true); }
         }
     }
 
@@ -229,13 +242,14 @@ struct jit_softmax_t: public jit_generator {
         auto accumulate_vmax = [&](int unroll, bool tail = false) {
             for (int i = 0; i < unroll; i++) {
                 if (!tail)
-                    uni_vmaxps(vmax, vmax, src_ptr(vlen * i));
+                    uni_vmaxps(vmax, vmax, src_ptr(axis_stride_ * i));
                 else {
                     if (isa == avx512_common)
-                        uni_vmaxps(vmax | ktail_mask, vmax, src_ptr(vlen * i));
+                        uni_vmaxps(vmax | ktail_mask, vmax,
+                                src_ptr(axis_stride_ * i));
                     else if (isa == avx2) {
                         vtmp = Vmm(i + 1);
-                        uni_vmovups_tail(vtmp, src_ptr(vlen * i));
+                        uni_vmovups_tail(vtmp, src_ptr(axis_stride_ * i));
                         uni_vblendvps(vtmp, vneg_flt_max, vtmp, vtail_mask);
                         uni_vmaxps(vmax, vmax, vtmp);
                     }
@@ -247,13 +261,13 @@ struct jit_softmax_t: public jit_generator {
             for (int i = 0; i < unroll; i++) {
                 Vmm vreg = Vmm(i + 1);
                 if (!tail) {
-                    uni_vmovups(vreg, src_ptr(vlen * i));
+                    uni_vmovups(vreg, src_ptr(axis_stride_ * i));
                     uni_vsubps(vreg, vreg, vmax);
                     eltwise_injector_->compute_vector(vreg.getIdx());
                     uni_vaddps(vsum, vsum, vreg);
-                    uni_vmovups(dst_ptr(vlen * i), vreg);
+                    uni_vmovups(dst_ptr(axis_stride_ * i), vreg);
                 } else {
-                    uni_vmovups_tail(vreg, src_ptr(vlen * i));
+                    uni_vmovups_tail(vreg, src_ptr(axis_stride_ * i));
                     uni_vsubps(vreg, vreg, vmax);
                     eltwise_injector_->compute_vector(vreg.getIdx());
                     if (isa == avx512_common)
@@ -264,7 +278,7 @@ struct jit_softmax_t: public jit_generator {
                         uni_vblendvps(vtmp, vtmp, vreg, vtail_mask);
                         uni_vaddps(vsum, vsum, vtmp);
                     }
-                    uni_vmovups_tail(dst_ptr(vlen * i), vreg);
+                    uni_vmovups_tail(dst_ptr(axis_stride_ * i), vreg);
                 }
             }
         };
@@ -273,21 +287,23 @@ struct jit_softmax_t: public jit_generator {
             for (int i = 0; i < unroll; i++) {
                 Vmm vreg = Vmm(i + 1);
                 if (!tail) {
-                    uni_vmulps(vreg, vsum, dst_ptr(vlen * i));
-                    uni_vmovups(dst_ptr(vlen * i), vreg);
+                    uni_vmulps(vreg, vsum, dst_ptr(axis_stride_ * i));
+                    uni_vmovups(dst_ptr(axis_stride_ * i), vreg);
                 } else {
                     if (isa == avx512_common)
-                        uni_vmulps(vreg | ktail_mask, vsum, dst_ptr(vlen * i));
+                        uni_vmulps(vreg | ktail_mask, vsum,
+                                dst_ptr(axis_stride_ * i));
                     else if (isa == avx2) {
-                        uni_vmovups_tail(vreg, dst_ptr(vlen * i));
+                        uni_vmovups_tail(vreg, dst_ptr(axis_stride_ * i));
                         uni_vmulps(vreg, vreg, vsum);
                     }
-                    uni_vmovups_tail(dst_ptr(vlen * i), vreg);
+                    uni_vmovups_tail(dst_ptr(axis_stride_ * i), vreg);
                 }
             }
         };
 
-        uni_vmovups(vmax, vneg_flt_max); // flush to -FLT_MAX before accumulation
+        // flush to -FLT_MAX before accumulation
+        uni_vmovups(vmax, vneg_flt_max);
         axis_loop(accumulate_vmax);
 
         get_horizontal_op(vmax, vtmp = vsum, op_t::max);
@@ -301,15 +317,15 @@ struct jit_softmax_t: public jit_generator {
         axis_loop(compute_dst);
     }
 
-    jit_softmax_t(const softmax_pd_t *sdesc): sdesc_(sdesc) {
+    jit_softmax_t(const softmax_pd_t *sdesc) : sdesc_(sdesc) {
         static_assert(utils::one_of(isa, sse41, avx2, avx512_common),
                 "unsupported isa");
 
         compute_predefined_variables();
 
-        eltwise_injector_ = new jit_uni_eltwise_injector_f32<isa>(
-                this, alg_kind::eltwise_exp, 0.0f, 0.0f, true,
-                reg_injector_table, injector_mask);
+        eltwise_injector_ = new jit_uni_eltwise_injector_f32<isa>(this,
+                alg_kind::eltwise_exp, 0.0f, 0.0f, true, reg_injector_table,
+                injector_mask);
 
         preamble();
 
@@ -329,25 +345,26 @@ struct jit_softmax_t: public jit_generator {
 
         eltwise_injector_->prepare_table();
 
-        ker = reinterpret_cast<decltype(ker)>(const_cast<uint8_t*>(
-                    this->getCode()));
+        ker = reinterpret_cast<decltype(ker)>(
+                const_cast<uint8_t *>(this->getCode()));
     }
 
-    ~jit_softmax_t() {
-        delete eltwise_injector_;
-    }
+    ~jit_softmax_t() { delete eltwise_injector_; }
 };
 
 // keep two sse41 functions separately to have common part human-friendly code
 template <>
 void jit_softmax_t<sse41>::uni_vmovups_tail(
-        const Operand &dst, const Operand &src) = delete;
+        const Operand &dst, const Operand &src)
+        = delete;
 template <>
 void jit_softmax_t<sse41>::uni_vmovups_tail_avx2(
-        const Operand &dst, const Operand &src) = delete;
+        const Operand &dst, const Operand &src)
+        = delete;
 template <>
 void jit_softmax_t<sse41>::uni_vmovups_tail_avx512(
-        const Operand &dst, const Operand &src) = delete;
+        const Operand &dst, const Operand &src)
+        = delete;
 
 template <>
 void jit_softmax_t<sse41>::get_horizontal_op(Vmm &v, Vmm &vtmp, op_t op) {
@@ -366,41 +383,44 @@ void jit_softmax_t<sse41>::forward() {
             Vmm vreg = Vmm(i + 1);
             if (!tail) {
                 // SIGSEGV on unaligned addr if do maxps directly on memory
-                uni_vmovups(vreg, src_ptr(vlen * i));
+                uni_vmovups(vreg, src_ptr(axis_stride_ * i));
                 uni_vmaxps(vmax, vmax, vreg);
             } else {
                 vtmp = Vmm(vreg.getIdx() + 1); // next after vreg
 
                 for (size_t j = 0; j < axis_simd_tail_; j++) {
                     uni_vmovups(vreg, vneg_flt_max);
-                    uni_vmovss(vtmp, src_ptr(vlen * i + sizeof(data_t) * j));
+                    uni_vmovss(vtmp,
+                            src_ptr(axis_stride_ * i + sizeof(data_t) * j));
                     uni_vblendvps(vreg, vreg, vtmp, vtail_mask);
                     uni_vmaxps(vmax, vmax, vreg);
                 }
             }
         }
-     };
+    };
 
     auto accumulate_vsum = [&](int unroll, bool tail = false) {
         for (int i = 0; i < unroll; i++) {
             Vmm vreg = Vmm(i + 1);
             if (!tail) {
-                uni_vmovups(vreg, src_ptr(vlen * i));
+                uni_vmovups(vreg, src_ptr(axis_stride_ * i));
                 uni_vsubps(vreg, vreg, vmax);
                 eltwise_injector_->compute_vector(vreg.getIdx());
                 uni_vaddps(vsum, vsum, vreg);
-                uni_vmovups(dst_ptr(vlen * i), vreg);
+                uni_vmovups(dst_ptr(axis_stride_ * i), vreg);
             } else {
                 vtmp = Vmm(vreg.getIdx() + 1); // next after vreg
 
                 for (size_t j = 0; j < axis_simd_tail_; j++) {
-                    uni_vmovss(vreg, src_ptr(vlen * i + sizeof(data_t) * j));
+                    uni_vmovss(vreg,
+                            src_ptr(axis_stride_ * i + sizeof(data_t) * j));
                     uni_vsubps(vreg, vreg, vmax);
                     eltwise_injector_->compute_vector(vreg.getIdx());
                     uni_vpxor(vtmp, vtmp, vtmp);
                     uni_vblendvps(vtmp, vtmp, vreg, vtail_mask);
                     uni_vaddps(vsum, vsum, vtmp);
-                    uni_vmovss(dst_ptr(vlen * i + sizeof(data_t) * j), vreg);
+                    uni_vmovss(dst_ptr(axis_stride_ * i + sizeof(data_t) * j),
+                            vreg);
                 }
             }
         }
@@ -410,14 +430,16 @@ void jit_softmax_t<sse41>::forward() {
         for (int i = 0; i < unroll; i++) {
             Vmm vreg = Vmm(i + 1);
             if (!tail) {
-                uni_vmovups(vreg, dst_ptr(vlen * i));
+                uni_vmovups(vreg, dst_ptr(axis_stride_ * i));
                 uni_vmulps(vreg, vreg, vsum);
-                uni_vmovups(dst_ptr(vlen * i), vreg);
+                uni_vmovups(dst_ptr(axis_stride_ * i), vreg);
             } else {
                 for (size_t j = 0; j < axis_simd_tail_; j++) {
-                    uni_vmovss(vreg, dst_ptr(vlen * i + sizeof(data_t) * j));
+                    uni_vmovss(vreg,
+                            dst_ptr(axis_stride_ * i + sizeof(data_t) * j));
                     uni_vmulps(vreg, vreg, vsum);
-                    uni_vmovss(dst_ptr(vlen * i + sizeof(data_t) * j), vreg);
+                    uni_vmovss(dst_ptr(axis_stride_ * i + sizeof(data_t) * j),
+                            vreg);
                 }
             }
         }
@@ -437,11 +459,11 @@ void jit_softmax_t<sse41>::forward() {
     axis_loop(compute_dst);
 }
 
-}
+} // namespace
 
 template <cpu_isa_t isa>
 jit_uni_softmax_fwd_t<isa>::jit_uni_softmax_fwd_t(const pd_t *apd)
-    : cpu_primitive_t(apd) {
+    : primitive_impl_t(apd) {
     softmax_driver_ = new softmax_impl::driver_t<isa>(pd());
 }
 
@@ -452,15 +474,24 @@ jit_uni_softmax_fwd_t<isa>::~jit_uni_softmax_fwd_t() {
 
 template <cpu_isa_t isa>
 status_t jit_uni_softmax_fwd_t<isa>::execute(const exec_ctx_t &ctx) const {
-    auto src = CTX_IN_MEM(const data_t *, MKLDNN_ARG_SRC);
-    auto dst = CTX_OUT_MEM(data_t *, MKLDNN_ARG_DST);
+    auto src = CTX_IN_MEM(const data_t *, DNNL_ARG_SRC);
+    auto dst = CTX_OUT_MEM(data_t *, DNNL_ARG_DST);
 
-    const auto ou_stride = pd()->outer_stride();
+    const memory_desc_wrapper data_d(pd()->src_md());
+    const auto &bd = data_d.blocking_desc();
+    const auto axis = pd()->axis();
 
-    parallel_nd(pd()->outer_size(), [&](int ou) {
-        const data_t *src_ptr = src + ou * ou_stride;
-        data_t *dst_ptr = dst + ou * ou_stride;
-        softmax_driver_->exec(src_ptr, dst_ptr);
+    const auto inner_stride
+            = bd.inner_nblks ? bd.inner_blks[bd.inner_nblks - 1] : (dim_t)1;
+    const auto inner_size = bd.strides[axis] / inner_stride;
+    const auto outer_stride = data_d.padded_dims()[axis] * inner_size;
+    const auto outer_size = data_d.nelems(true) / outer_stride;
+
+    parallel_nd(outer_size, inner_size, [&](dim_t ou, dim_t in) {
+        dim_t offset = ou * outer_stride + in * inner_stride;
+        const data_t *src_ptr = src + offset;
+        data_t *dst_ptr = dst + offset;
+        softmax_driver_->exec(src_ptr, dst_ptr, outer_stride);
     });
 
     return status::success;
@@ -469,15 +500,14 @@ status_t jit_uni_softmax_fwd_t<isa>::execute(const exec_ctx_t &ctx) const {
 namespace softmax_impl {
 
 template <cpu_isa_t isa>
-struct driver_t: public c_compatible {
+struct driver_t : public c_compatible {
 
-    driver_t(const softmax_pd_t *sdesc)
-        : sdesc_(sdesc), ker_(sdesc_) {}
+    driver_t(const softmax_pd_t *sdesc) : sdesc_(sdesc), ker_(sdesc_) {}
     ~driver_t() {}
 
-    void exec(const data_t *src, data_t *dst) {
+    void exec(const data_t *src, data_t *dst, const dim_t outer_stride) {
         typename jit_softmax_t<isa>::call_params_t p;
-        p.soff_max = sizeof(data_t) * sdesc_->axis_size();
+        p.soff_max = outer_stride * sizeof(data_t);
         p.src = src;
         p.dst = dst;
         ker_(&p);
@@ -489,13 +519,13 @@ private:
     jit_softmax_t<isa> ker_;
 };
 
-}
+} // namespace softmax_impl
 
 /* struct instantiation */
 template struct jit_uni_softmax_fwd_t<sse41>;
 template struct jit_uni_softmax_fwd_t<avx2>;
 template struct jit_uni_softmax_fwd_t<avx512_common>;
 
-}
-}
-}
+} // namespace cpu
+} // namespace impl
+} // namespace dnnl
