@@ -18,14 +18,14 @@
 #include <math.h>
 
 #include "c_types_map.hpp"
-#include "type_helpers.hpp"
+#include "dnnl_thread.hpp"
 #include "math_utils.hpp"
-#include "mkldnn_thread.hpp"
 #include "nstl.hpp"
+#include "type_helpers.hpp"
 
 #include "nchw_pooling.hpp"
 
-namespace mkldnn {
+namespace dnnl {
 namespace impl {
 namespace cpu {
 
@@ -36,9 +36,9 @@ void nchw_pooling_fwd_t<d_type>::execute_forward(const exec_ctx_t &ctx) const {
 
     auto alg = pd()->desc()->alg_kind;
 
-    auto src = CTX_IN_MEM(const data_t *, MKLDNN_ARG_SRC);
-    auto dst = CTX_OUT_MEM(data_t *, MKLDNN_ARG_DST);
-    auto ws = CTX_OUT_MEM(unsigned char *, MKLDNN_ARG_WORKSPACE);
+    auto src = CTX_IN_MEM(const data_t *, DNNL_ARG_SRC);
+    auto dst = CTX_OUT_MEM(data_t *, DNNL_ARG_DST);
+    auto ws = CTX_OUT_MEM(unsigned char *, DNNL_ARG_WORKSPACE);
 
     const memory_desc_wrapper ws_d(pd()->workspace_md());
     const data_type_t ws_dt = ws ? ws_d.data_type() : data_type::undef;
@@ -68,15 +68,13 @@ void nchw_pooling_fwd_t<d_type>::execute_forward(const exec_ctx_t &ctx) const {
     auto set_ws = [=](int mb, int c, int od, int oh, int ow, int value) {
         if (ws) {
             assert(ws_dt == data_type::u8 || ws_dt == data_type::s32);
-            size_t ws_offset
-                = (size_t)OW * OH * OD * C * mb
-                + (size_t)OW * OH * OD * c
-                + (size_t)OW * OH * od
-                + (size_t)OW * oh
-                + (size_t)ow;
+            size_t ws_offset = (size_t)OW * OH * OD * C * mb
+                    + (size_t)OW * OH * OD * c + (size_t)OW * OH * od
+                    + (size_t)OW * oh + (size_t)ow;
             if (ws_dt == data_type::u8) {
-                assert(0 <= value && value <= numeric_limits<
-                    typename prec_traits<data_type::u8>::type>::max());
+                assert(0 <= value
+                        && value <= numeric_limits<typename prec_traits<
+                                        data_type::u8>::type>::max());
                 ws[ws_offset] = value;
             } else
                 reinterpret_cast<int *>(ws)[ws_offset] = value;
@@ -84,8 +82,8 @@ void nchw_pooling_fwd_t<d_type>::execute_forward(const exec_ctx_t &ctx) const {
     };
 
     auto ker_max = [=](data_t *d, int mb, int c, int od, int oh, int ow) {
-        for (int kd = 0; kd < KD; ++kd)
-        for (int kh = 0; kh < KH; ++kh)
+        for_(int kd = 0; kd < KD; ++kd)
+        for_(int kh = 0; kh < KH; ++kh)
         for (int kw = 0; kw < KW; ++kw) {
             const int id = od * SD - padF + kd;
             const int ih = oh * SH - padT + kh;
@@ -115,11 +113,12 @@ void nchw_pooling_fwd_t<d_type>::execute_forward(const exec_ctx_t &ctx) const {
         auto iw_end = min(ow * SW - padL + KW, IW);
 
         auto num_summands = (alg == alg_kind::pooling_avg_include_padding)
-            ? KD * KW * KH
-            : (id_end - id_start) * (ih_end - ih_start) * (iw_end - iw_start);
+                ? KD * KW * KH
+                : (id_end - id_start) * (ih_end - ih_start)
+                        * (iw_end - iw_start);
 
-        for (int id = id_start; id < id_end; ++id)
-        for (int ih = ih_start; ih < ih_end; ++ih)
+        for_(int id = id_start; id < id_end; ++id)
+        for_(int ih = ih_start; ih < ih_end; ++ih)
         for (int iw = iw_start; iw < iw_end; ++iw) {
             auto src_offset = (size_t)IW * IH * ID * C * mb
                     + (size_t)IW * IH * ID * c + (size_t)IW * IH * id
@@ -131,32 +130,26 @@ void nchw_pooling_fwd_t<d_type>::execute_forward(const exec_ctx_t &ctx) const {
     };
 
     if (alg == alg_kind::pooling_max) {
-        parallel_nd(MB, C, OD, OH, OW,
-            [&](int mb, int c, int od, int oh, int ow) {
-            size_t dst_offset
-                = (size_t)OW * OH * OD * C * mb
-                + (size_t)OW * OH * OD * c
-                + (size_t)OW * OH * od
-                + (size_t)OW * oh
-                + (size_t)ow;
-            data_t *d = &dst[dst_offset];
-            d[0] = numeric_limits<data_t>::lowest();
-            set_ws(mb, c, od, oh, ow, 0);
-            ker_max(d, mb, c, od, oh, ow);
-        });
+        parallel_nd(
+                MB, C, OD, OH, OW, [&](int mb, int c, int od, int oh, int ow) {
+                    size_t dst_offset = (size_t)OW * OH * OD * C * mb
+                            + (size_t)OW * OH * OD * c + (size_t)OW * OH * od
+                            + (size_t)OW * oh + (size_t)ow;
+                    data_t *d = &dst[dst_offset];
+                    d[0] = numeric_limits<data_t>::lowest();
+                    set_ws(mb, c, od, oh, ow, 0);
+                    ker_max(d, mb, c, od, oh, ow);
+                });
     } else {
-        parallel_nd(MB, C, OD, OH, OW,
-            [&](int mb, int c, int od, int oh, int ow) {
-            size_t dst_offset
-                = (size_t)OW * OH * OD * C * mb
-                + (size_t)OW * OH * OD * c
-                + (size_t)OW * OH * od
-                + (size_t)OW * oh
-                + (size_t)ow;
-            data_t *d = &dst[dst_offset];
-            d[0] = 0;
-            ker_avg(d, mb, c, od, oh, ow);
-        });
+        parallel_nd(
+                MB, C, OD, OH, OW, [&](int mb, int c, int od, int oh, int ow) {
+                    size_t dst_offset = (size_t)OW * OH * OD * C * mb
+                            + (size_t)OW * OH * OD * c + (size_t)OW * OH * od
+                            + (size_t)OW * oh + (size_t)ow;
+                    data_t *d = &dst[dst_offset];
+                    d[0] = 0;
+                    ker_avg(d, mb, c, od, oh, ow);
+                });
     }
 }
 
@@ -166,11 +159,11 @@ void nchw_pooling_fwd_t<data_type::bf16>::execute_forward(
 
     auto alg = pd()->desc()->alg_kind;
 
-    auto src = CTX_IN_MEM(const bfloat16_t *, MKLDNN_ARG_SRC);
-    auto dst = CTX_OUT_MEM(bfloat16_t *, MKLDNN_ARG_DST);
-    auto ws = CTX_OUT_MEM(unsigned char *, MKLDNN_ARG_WORKSPACE);
+    auto src = CTX_IN_MEM(const bfloat16_t *, DNNL_ARG_SRC);
+    auto dst = CTX_OUT_MEM(bfloat16_t *, DNNL_ARG_DST);
+    auto ws = CTX_OUT_MEM(unsigned char *, DNNL_ARG_WORKSPACE);
 
-    auto scratchpad = this->scratchpad(ctx);
+    auto scratchpad = ctx.get_scratchpad_grantor();
     float *bf16cvt_wsp = scratchpad.template get<float>(
             memory_tracking::names::key_pool_src_bf16cvt);
 
@@ -207,15 +200,13 @@ void nchw_pooling_fwd_t<data_type::bf16>::execute_forward(
     auto set_ws = [=](int mb, int c, int od, int oh, int ow, int value) {
         if (ws) {
             assert(ws_dt == data_type::u8 || ws_dt == data_type::s32);
-            size_t ws_offset
-                = (size_t)OW * OH * OD * C * mb
-                + (size_t)OW * OH * OD * c
-                + (size_t)OW * OH * od
-                + (size_t)OW * oh
-                + (size_t)ow;
+            size_t ws_offset = (size_t)OW * OH * OD * C * mb
+                    + (size_t)OW * OH * OD * c + (size_t)OW * OH * od
+                    + (size_t)OW * oh + (size_t)ow;
             if (ws_dt == data_type::u8) {
-                assert(0 <= value && value <= numeric_limits<
-                    typename prec_traits<data_type::u8>::type>::max());
+                assert(0 <= value
+                        && value <= numeric_limits<typename prec_traits<
+                                        data_type::u8>::type>::max());
                 ws[ws_offset] = value;
             } else
                 reinterpret_cast<int *>(ws)[ws_offset] = value;
@@ -223,8 +214,8 @@ void nchw_pooling_fwd_t<data_type::bf16>::execute_forward(
     };
 
     auto ker_max = [=](float *d, int mb, int c, int od, int oh, int ow) {
-        for (int kd = 0; kd < KD; ++kd)
-        for (int kh = 0; kh < KH; ++kh)
+        for_(int kd = 0; kd < KD; ++kd)
+        for_(int kh = 0; kh < KH; ++kh)
         for (int kw = 0; kw < KW; ++kw) {
             const int id = od * SD - padF + kd;
             const int ih = oh * SH - padT + kh;
@@ -234,12 +225,9 @@ void nchw_pooling_fwd_t<data_type::bf16>::execute_forward(
             if (ih < 0 || ih >= IH) continue;
             if (iw < 0 || iw >= IW) continue;
 
-            auto src_offset
-                = (size_t)IW * IH * ID * C * mb
-                + (size_t)IW * IH * ID * c
-                + (size_t)IW * IH * id
-                + (size_t)IW * ih
-                + (size_t)iw;
+            auto src_offset = (size_t)IW * IH * ID * C * mb
+                    + (size_t)IW * IH * ID * c + (size_t)IW * IH * id
+                    + (size_t)IW * ih + (size_t)iw;
             auto s = bf16cvt_wsp[src_offset];
 
             if (s > d[0]) {
@@ -258,18 +246,16 @@ void nchw_pooling_fwd_t<data_type::bf16>::execute_forward(
         auto iw_end = min(ow * SW - padL + KW, IW);
 
         auto num_summands = (alg == alg_kind::pooling_avg_include_padding)
-            ? KD * KW * KH
-            : (id_end - id_start) * (ih_end - ih_start) * (iw_end - iw_start);
+                ? KD * KW * KH
+                : (id_end - id_start) * (ih_end - ih_start)
+                        * (iw_end - iw_start);
 
-        for (int id = id_start; id < id_end; ++id)
-        for (int ih = ih_start; ih < ih_end; ++ih)
+        for_(int id = id_start; id < id_end; ++id)
+        for_(int ih = ih_start; ih < ih_end; ++ih)
         for (int iw = iw_start; iw < iw_end; ++iw) {
-            auto src_offset
-                = (size_t)IW * IH * ID * C * mb
-                + (size_t)IW * IH * ID * c
-                + (size_t)IW * IH * id
-                + (size_t)IW * ih
-                + (size_t)iw;
+            auto src_offset = (size_t)IW * IH * ID * C * mb
+                    + (size_t)IW * IH * ID * c + (size_t)IW * IH * id
+                    + (size_t)IW * ih + (size_t)iw;
             d[0] += bf16cvt_wsp[src_offset];
         }
 
@@ -283,37 +269,31 @@ void nchw_pooling_fwd_t<data_type::bf16>::execute_forward(
         cvt_bfloat16_to_float(&bf16cvt_wsp[blocked_size * simd_w],
                 &src[blocked_size * simd_w], tail_size);
     if (alg == alg_kind::pooling_max) {
-        parallel_nd(MB, C, OD, OH, OW,
-            [&](int mb, int c, int od, int oh, int ow) {
-            size_t dst_offset
-                = (size_t)OW * OH * OD * C * mb
-                + (size_t)OW * OH * OD * c
-                + (size_t)OW * OH * od
-                + (size_t)OW * oh
-                + (size_t)ow;
-            float d_fp32 = numeric_limits<bfloat16_t>::lowest();
+        parallel_nd(
+                MB, C, OD, OH, OW, [&](int mb, int c, int od, int oh, int ow) {
+                    size_t dst_offset = (size_t)OW * OH * OD * C * mb
+                            + (size_t)OW * OH * OD * c + (size_t)OW * OH * od
+                            + (size_t)OW * oh + (size_t)ow;
+                    float d_fp32 = numeric_limits<bfloat16_t>::lowest();
 
-            set_ws(mb, c, od, oh, ow, 0);
+                    set_ws(mb, c, od, oh, ow, 0);
 
-            ker_max(&d_fp32, mb, c, od, oh, ow);
+                    ker_max(&d_fp32, mb, c, od, oh, ow);
 
-            dst[dst_offset] = (bfloat16_t)d_fp32;
-        });
+                    dst[dst_offset] = (bfloat16_t)d_fp32;
+                });
     } else {
-        parallel_nd(MB, C, OD, OH, OW,
-            [&](int mb, int c, int od, int oh, int ow) {
-            size_t dst_offset
-                = (size_t)OW * OH * OD * C * mb
-                + (size_t)OW * OH * OD * c
-                + (size_t)OW * OH * od
-                + (size_t)OW * oh
-                + (size_t)ow;
-            float d_fp32 = 0.0f;
+        parallel_nd(
+                MB, C, OD, OH, OW, [&](int mb, int c, int od, int oh, int ow) {
+                    size_t dst_offset = (size_t)OW * OH * OD * C * mb
+                            + (size_t)OW * OH * OD * c + (size_t)OW * OH * od
+                            + (size_t)OW * oh + (size_t)ow;
+                    float d_fp32 = 0.0f;
 
-            ker_avg(&d_fp32, mb, c, od, oh, ow);
+                    ker_avg(&d_fp32, mb, c, od, oh, ow);
 
-            dst[dst_offset] = (bfloat16_t)d_fp32;
-        });
+                    dst[dst_offset] = (bfloat16_t)d_fp32;
+                });
     }
 }
 
@@ -323,9 +303,9 @@ void nchw_pooling_bwd_t<d_type>::execute_backward(const exec_ctx_t &ctx) const {
     auto alg = pd()->desc()->alg_kind;
     const bool is_3d = pd()->desc()->diff_src_desc.ndims == 5;
 
-    auto diff_src = CTX_OUT_MEM(data_t *, MKLDNN_ARG_DIFF_SRC);
-    auto diff_dst = CTX_IN_MEM(const data_t *, MKLDNN_ARG_DIFF_DST);
-    auto ws = CTX_IN_MEM(const unsigned char *, MKLDNN_ARG_WORKSPACE);
+    auto diff_src = CTX_OUT_MEM(data_t *, DNNL_ARG_DIFF_SRC);
+    auto diff_dst = CTX_IN_MEM(const data_t *, DNNL_ARG_DIFF_DST);
+    auto ws = CTX_IN_MEM(const unsigned char *, DNNL_ARG_WORKSPACE);
 
     const memory_desc_wrapper ws_d(pd()->workspace_md());
 
@@ -354,8 +334,8 @@ void nchw_pooling_bwd_t<d_type>::execute_backward(const exec_ctx_t &ctx) const {
     auto ker_zero = [=](int mb, int c) {
         size_t diff_src_offset
                 = (size_t)mb * C * ID * IH * IW + (size_t)c * ID * IH * IW;
-        for (int id = 0; id < ID; ++id)
-        for (int ih = 0; ih < IH; ++ih)
+        for_(int id = 0; id < ID; ++id)
+        for_(int ih = 0; ih < IH; ++ih)
         for (int iw = 0; iw < IW; ++iw) {
             diff_src[diff_src_offset++] = 0;
         }
@@ -406,8 +386,8 @@ void nchw_pooling_bwd_t<d_type>::execute_backward(const exec_ctx_t &ctx) const {
                 : (size_t)(id_end - id_start) * (ih_end - ih_start)
                         * (iw_end - iw_start);
 
-        for (int id = id_start; id < id_end; ++id)
-        for (int ih = ih_start; ih < ih_end; ++ih)
+        for_(int id = id_start; id < id_end; ++id)
+        for_(int ih = ih_start; ih < ih_end; ++ih)
         for (int iw = iw_start; iw < iw_end; ++iw) {
             size_t diff_src_offset = (size_t)mb * C * ID * IH * IW
                     + (size_t)c * ID * IH * IW + (size_t)id * IH * IW
@@ -430,7 +410,7 @@ void nchw_pooling_bwd_t<d_type>::execute_backward(const exec_ctx_t &ctx) const {
             size_t diff_dst_offset_b
                     = (size_t)mb * C * OD * OH * OW + (size_t)c * OD * OH * OW;
             ker_zero(mb, c);
-            for (int od = od_start; od < od_end; ++od)
+            for_(int od = od_start; od < od_end; ++od)
             for (int oh = oh_start; oh < oh_end; ++oh) {
                 size_t diff_dst_offset = diff_dst_offset_b
                         + (size_t)od * OH * OW + (size_t)oh * OW;
@@ -445,7 +425,7 @@ void nchw_pooling_bwd_t<d_type>::execute_backward(const exec_ctx_t &ctx) const {
             size_t diff_dst_offset_b
                     = (size_t)mb * C * OD * OH * OW + (size_t)c * OD * OH * OW;
             ker_zero(mb, c);
-            for (int od = od_start; od < od_end; ++od)
+            for_(int od = od_start; od < od_end; ++od)
             for (int oh = oh_start; oh < oh_end; ++oh) {
                 size_t diff_dst_offset = diff_dst_offset_b
                         + (size_t)od * OH * OW + (size_t)oh * OW;
@@ -465,11 +445,11 @@ void nchw_pooling_bwd_t<data_type::bf16>::execute_backward(
     auto alg = pd()->desc()->alg_kind;
     const bool is_3d = pd()->desc()->diff_src_desc.ndims == 5;
 
-    auto diff_src = CTX_OUT_MEM(bfloat16_t *, MKLDNN_ARG_DIFF_SRC);
-    auto diff_dst = CTX_IN_MEM(const bfloat16_t *, MKLDNN_ARG_DIFF_DST);
-    auto ws = CTX_IN_MEM(const unsigned char *, MKLDNN_ARG_WORKSPACE);
+    auto diff_src = CTX_OUT_MEM(bfloat16_t *, DNNL_ARG_DIFF_SRC);
+    auto diff_dst = CTX_IN_MEM(const bfloat16_t *, DNNL_ARG_DIFF_DST);
+    auto ws = CTX_IN_MEM(const unsigned char *, DNNL_ARG_WORKSPACE);
 
-    auto scratchpad = this->scratchpad(ctx);
+    auto scratchpad = ctx.get_scratchpad_grantor();
     float *bf16cvt_src = scratchpad.template get<float>(
             memory_tracking::names::key_pool_src_bf16cvt);
     float *bf16cvt_dst = scratchpad.template get<float>(
@@ -504,15 +484,15 @@ void nchw_pooling_bwd_t<data_type::bf16>::execute_backward(
 
     auto ker_zero = [=](float *diff_src) {
         size_t diff_src_offset = 0;
-        for (int id = 0; id < ID; ++id)
-        for (int ih = 0; ih < IH; ++ih)
+        for_(int id = 0; id < ID; ++id)
+        for_(int ih = 0; ih < IH; ++ih)
         for (int iw = 0; iw < IW; ++iw) {
             diff_src[diff_src_offset++] = 0.0f;
         }
     };
 
     auto ker_max = [=](const float *d, float *diff_src, int mb, int c, int od,
-            int oh, int ow) {
+                           int oh, int ow) {
         auto b_c = ws_d.blocking_desc().inner_nblks == 0
                 ? 1
                 : ws_d.blocking_desc().inner_blks[0];
@@ -544,7 +524,7 @@ void nchw_pooling_bwd_t<data_type::bf16>::execute_backward(
     };
 
     auto ker_avg = [=](const float *d, float *diff_src, int mb, int c, int od,
-            int oh, int ow) {
+                           int oh, int ow) {
         auto id_start = apply_offset(od * SD, padF);
         auto ih_start = apply_offset(oh * SH, padT);
         auto iw_start = apply_offset(ow * SW, padL);
@@ -557,8 +537,8 @@ void nchw_pooling_bwd_t<data_type::bf16>::execute_backward(
                 : (size_t)(id_end - id_start) * (ih_end - ih_start)
                         * (iw_end - iw_start);
 
-        for (int id = id_start; id < id_end; ++id)
-        for (int ih = ih_start; ih < ih_end; ++ih)
+        for_(int id = id_start; id < id_end; ++id)
+        for_(int ih = ih_start; ih < ih_end; ++ih)
         for (int iw = iw_start; iw < iw_end; ++iw) {
             size_t diff_src_offset
                     = (size_t)id * IH * IW + (size_t)ih * IW + (size_t)iw;
@@ -582,19 +562,18 @@ void nchw_pooling_bwd_t<data_type::bf16>::execute_backward(
             size_t diff_src_offset
                     = ((size_t)mb * C + (size_t)c) * ID * IH * IW;
             float *diff_dst_fp32
-                    = &bf16cvt_dst[mkldnn_get_thread_num() * dst_sp_size];
+                    = &bf16cvt_dst[dnnl_get_thread_num() * dst_sp_size];
             float *diff_src_fp32
-                    = &bf16cvt_src[mkldnn_get_thread_num() * src_sp_size];
+                    = &bf16cvt_src[dnnl_get_thread_num() * src_sp_size];
 
             ker_zero(diff_src_fp32);
 
             cvt_bfloat16_to_float(
                     diff_dst_fp32, &diff_dst[diff_dst_offset_b], dst_sp_size);
 
-            for (int od = od_start; od < od_end; ++od)
+            for_(int od = od_start; od < od_end; ++od)
             for (int oh = oh_start; oh < oh_end; ++oh) {
-                size_t diff_dst_offset
-                        = (size_t)od * OH * OW + (size_t)oh * OW;
+                size_t diff_dst_offset = (size_t)od * OH * OW + (size_t)oh * OW;
                 for (int ow = ow_start; ow < ow_end; ++ow) {
                     const float *d = &diff_dst_fp32[diff_dst_offset + ow];
                     ker_max(d, diff_src_fp32, mb, c, od, oh, ow);
@@ -608,21 +587,20 @@ void nchw_pooling_bwd_t<data_type::bf16>::execute_backward(
             size_t diff_dst_offset_b
                     = (size_t)mb * C * OD * OH * OW + (size_t)c * OD * OH * OW;
             float *diff_dst_fp32
-                    = &bf16cvt_dst[mkldnn_get_thread_num() * dst_sp_size];
+                    = &bf16cvt_dst[dnnl_get_thread_num() * dst_sp_size];
             size_t diff_src_offset
                     = (size_t)mb * C * ID * IH * IW + (size_t)c * ID * IH * IW;
             float *diff_src_fp32
-                    = &bf16cvt_src[mkldnn_get_thread_num() * src_sp_size];
+                    = &bf16cvt_src[dnnl_get_thread_num() * src_sp_size];
 
             ker_zero(diff_src_fp32);
 
             cvt_bfloat16_to_float(
                     diff_dst_fp32, &diff_dst[diff_dst_offset_b], dst_sp_size);
 
-            for (int od = od_start; od < od_end; ++od)
+            for_(int od = od_start; od < od_end; ++od)
             for (int oh = oh_start; oh < oh_end; ++oh) {
-                size_t diff_dst_offset
-                        = (size_t)od * OH * OW + (size_t)oh * OW;
+                size_t diff_dst_offset = (size_t)od * OH * OW + (size_t)oh * OW;
                 for (int ow = ow_start; ow < ow_end; ++ow) {
                     const float *d = &diff_dst_fp32[diff_dst_offset + ow];
                     ker_avg(d, diff_src_fp32, mb, c, od, oh, ow);
@@ -637,8 +615,8 @@ template struct nchw_pooling_fwd_t<data_type::f32>;
 template struct nchw_pooling_bwd_t<data_type::f32>;
 template struct nchw_pooling_fwd_t<data_type::bf16>;
 template struct nchw_pooling_bwd_t<data_type::bf16>;
-}
-}
-}
+} // namespace cpu
+} // namespace impl
+} // namespace dnnl
 
-// vim: et ts=4 sw=4 cindent cino^=l0,\:0,N-s
+// vim: et ts=4 sw=4 cindent cino+=l0,\:4,N-s
