@@ -18,8 +18,8 @@
 #include <math.h>
 
 #include "c_types_map.hpp"
+#include "dnnl_thread.hpp"
 #include "type_helpers.hpp"
-#include "mkldnn_thread.hpp"
 
 #include "cpu_batch_normalization_utils.hpp"
 
@@ -32,7 +32,7 @@
 #define SAFE_TO_USE_OMP_SIMD 1
 #endif
 
-namespace mkldnn {
+namespace dnnl {
 namespace impl {
 namespace cpu {
 
@@ -48,32 +48,32 @@ void nspc_batch_normalization_fwd_t<d_type>::execute_forward(
     const bool calculate_stats = !pd()->stats_is_src();
     const bool with_relu = pd()->with_relu_post_op();
 
-    auto scratchpad = this->scratchpad(ctx);
+    auto scratchpad = ctx.get_scratchpad_grantor();
     auto tmp_mean = scratchpad.template get<acc_data_t>(key_bnorm_tmp_mean);
     auto tmp_var = scratchpad.template get<acc_data_t>(key_bnorm_tmp_var);
     auto *ws_reduce = scratchpad.template get<acc_data_t>(key_bnorm_reduction);
 
-    auto src = CTX_IN_MEM(const data_t *, MKLDNN_ARG_SRC);
-    auto scaleshift = CTX_IN_MEM(const acc_data_t *, MKLDNN_ARG_SCALE_SHIFT);
+    auto src = CTX_IN_MEM(const data_t *, DNNL_ARG_SRC);
+    auto scaleshift = CTX_IN_MEM(const acc_data_t *, DNNL_ARG_SCALE_SHIFT);
 
     acc_data_t *mean, *variance;
     if (!calculate_stats) {
         mean = const_cast<acc_data_t *>(
-                CTX_IN_MEM(const acc_data_t *, MKLDNN_ARG_MEAN));
+                CTX_IN_MEM(const acc_data_t *, DNNL_ARG_MEAN));
         variance = const_cast<acc_data_t *>(
-                CTX_IN_MEM(const acc_data_t *, MKLDNN_ARG_VARIANCE));
+                CTX_IN_MEM(const acc_data_t *, DNNL_ARG_VARIANCE));
     } else {
         if (save_stats) {
-            mean = CTX_OUT_MEM(acc_data_t *, MKLDNN_ARG_MEAN);
-            variance = CTX_OUT_MEM(acc_data_t *, MKLDNN_ARG_VARIANCE);
+            mean = CTX_OUT_MEM(acc_data_t *, DNNL_ARG_MEAN);
+            variance = CTX_OUT_MEM(acc_data_t *, DNNL_ARG_VARIANCE);
         } else {
             mean = tmp_mean;
             variance = tmp_var;
         }
     }
 
-    auto dst = CTX_OUT_MEM(data_t *, MKLDNN_ARG_DST);
-    auto ws = CTX_OUT_MEM(uint8_t *, MKLDNN_ARG_WORKSPACE);
+    auto dst = CTX_OUT_MEM(data_t *, DNNL_ARG_DST);
+    auto ws = CTX_OUT_MEM(uint8_t *, DNNL_ARG_WORKSPACE);
     acc_data_t *tmp_data_ = d_type == bf16
             ? scratchpad.template get<acc_data_t>(key_bnorm_bf16cvt)
             : nullptr;
@@ -88,16 +88,13 @@ void nspc_batch_normalization_fwd_t<d_type>::execute_forward(
     const bool use_scaleshift = pd()->use_scaleshift();
     auto maybe_post_op
             = [&](acc_data_t res) { return (with_relu && res < 0) ? 0 : res; };
+    int nthr = dnnl_get_max_threads();
 
-    assert(mkldnn_thr_syncable());
-    parallel(0, [&](const int ithr, const int nthr) {
-        dim_t N_s = 0, N_e = 0, C_s = 0, C_e = 0;
-        balance211(N, nthr, ithr, N_s, N_e);
-        balance211(C, nthr, ithr, C_s, C_e);
-        acc_data_t *mean_loc = tmp_mean + nstl::max(C, (dim_t)16) * ithr;
-        acc_data_t *variance_loc = tmp_var + nstl::max(C, (dim_t)16) * ithr;
+    if (calculate_stats) {
+        parallel(nthr, [&](const int ithr, const int nthr) {
+            dim_t N_s = 0, N_e = 0;
+            balance211(N, nthr, ithr, N_s, N_e);
 
-        if (calculate_stats) {
             for (dim_t c = 0; c < C; c++)
                 ws_reduce[C * ithr + c] = 0.;
 
@@ -121,17 +118,18 @@ void nspc_batch_normalization_fwd_t<d_type>::execute_forward(
                     }
                 }
             }
+        });
+        parallel_nd(C, [&](dim_t c) {
+            mean[c] = 0;
+            for (dim_t n = 0; n < nthr; n++)
+                mean[c] += ws_reduce[C * n + c];
+            mean[c] /= SP * N;
+        });
+        parallel(nthr, [&](const int ithr, const int nthr) {
+            dim_t N_s = 0, N_e = 0;
+            balance211(N, nthr, ithr, N_s, N_e);
 
-            mkldnn_thr_barrier();
-
-            for (dim_t c = C_s; c < C_e; c++) {
-                mean[c] = 0;
-                for (dim_t n = 0; n < nthr; n++)
-                    mean[c] += ws_reduce[C * n + c];
-                mean[c] /= SP * N;
-            }
-
-            mkldnn_thr_barrier();
+            acc_data_t *mean_loc = tmp_mean + nstl::max(C, (dim_t)16) * ithr;
 
             for (dim_t c = 0; c < C; c++) {
                 mean_loc[c] = mean[c];
@@ -159,23 +157,31 @@ void nspc_batch_normalization_fwd_t<d_type>::execute_forward(
                     }
                 }
             }
-
-            mkldnn_thr_barrier();
-
-            for (dim_t c = C_s; c < C_e; c++) {
-                variance[c] = 0;
-                for (dim_t n = 0; n < nthr; n++)
-                    variance[c] += ws_reduce[C * n + c];
-                variance[c] /= SP * N;
-            }
-
-            mkldnn_thr_barrier();
-
+        });
+        parallel_nd(C, [&](dim_t c) {
+            variance[c] = 0;
+            for (dim_t n = 0; n < nthr; n++)
+                variance[c] += ws_reduce[C * n + c];
+            variance[c] /= SP * N;
+        });
+        parallel(nthr, [&](const int ithr, const int nthr) {
+            acc_data_t *variance_loc = tmp_var + nstl::max(C, (dim_t)16) * ithr;
             for (dim_t c = 0; c < C; c++)
                 variance_loc[c] = variance[c];
+        });
+    }
+
+    parallel(nthr, [&](const int ithr, const int nthr) {
+        dim_t N_s = 0, N_e = 0;
+        balance211(N, nthr, ithr, N_s, N_e);
+
+        acc_data_t *mean_loc, *variance_loc;
+        if (calculate_stats) {
+            mean_loc = tmp_mean + nstl::max(C, (dim_t)16) * ithr;
+            variance_loc = tmp_var + nstl::max(C, (dim_t)16) * ithr;
         } else {
-            variance_loc = variance;
             mean_loc = mean;
+            variance_loc = variance;
         }
 
         for (dim_t n = N_s; n < N_e; n++) {
@@ -212,11 +218,9 @@ void nspc_batch_normalization_fwd_t<d_type>::execute_forward(
                     if (fuse_norm_relu) {
                         if (bn_res <= 0) {
                             bn_res = 0;
-                            if (is_training)
-                                ws[c_off] = 0;
+                            if (is_training) ws[c_off] = 0;
                         } else {
-                            if (is_training)
-                                ws[c_off] = 1;
+                            if (is_training) ws[c_off] = 1;
                         }
                     }
                     _dst[c] = maybe_post_op(bn_res);
@@ -236,23 +240,21 @@ template struct nspc_batch_normalization_fwd_t<bf16>;
 template <data_type_t d_type>
 void nspc_batch_normalization_bwd_t<d_type>::execute_backward(
         const exec_ctx_t &ctx) const {
-    auto src = CTX_IN_MEM(const data_t *, MKLDNN_ARG_SRC);
-    auto mean = CTX_IN_MEM(const acc_data_t *, MKLDNN_ARG_MEAN);
-    auto variance = CTX_IN_MEM(const acc_data_t *, MKLDNN_ARG_VARIANCE);
-    auto diff_dst = CTX_IN_MEM(const data_t *, MKLDNN_ARG_DIFF_DST);
-    auto scaleshift = CTX_IN_MEM(const acc_data_t *, MKLDNN_ARG_SCALE_SHIFT);
-    auto ws = CTX_IN_MEM(const uint8_t *, MKLDNN_ARG_WORKSPACE);
+    auto src = CTX_IN_MEM(const data_t *, DNNL_ARG_SRC);
+    auto mean = CTX_IN_MEM(const acc_data_t *, DNNL_ARG_MEAN);
+    auto variance = CTX_IN_MEM(const acc_data_t *, DNNL_ARG_VARIANCE);
+    auto diff_dst = CTX_IN_MEM(const data_t *, DNNL_ARG_DIFF_DST);
+    auto scaleshift = CTX_IN_MEM(const acc_data_t *, DNNL_ARG_SCALE_SHIFT);
+    auto ws = CTX_IN_MEM(const uint8_t *, DNNL_ARG_WORKSPACE);
 
-    auto diff_src = CTX_OUT_MEM(data_t *, MKLDNN_ARG_DIFF_SRC);
-    auto diff_scaleshift
-            = CTX_OUT_MEM(acc_data_t *, MKLDNN_ARG_DIFF_SCALE_SHIFT);
+    auto diff_src = CTX_OUT_MEM(data_t *, DNNL_ARG_DIFF_SRC);
+    auto diff_scaleshift = CTX_OUT_MEM(acc_data_t *, DNNL_ARG_DIFF_SCALE_SHIFT);
 
-    auto scratchpad = this->scratchpad(ctx);
+    auto scratchpad = ctx.get_scratchpad_grantor();
     auto tmp_diff_ss
             = scratchpad.template get<acc_data_t>(key_bnorm_tmp_diff_ss);
 
-    if (diff_scaleshift == nullptr)
-        diff_scaleshift = tmp_diff_ss;
+    if (diff_scaleshift == nullptr) diff_scaleshift = tmp_diff_ss;
 
     const dim_t N = pd()->MB();
     const dim_t C = pd()->C();
@@ -271,14 +273,16 @@ void nspc_batch_normalization_bwd_t<d_type>::execute_backward(
     const bool calculate_diff_stats = !pd()->use_global_stats();
     const bool fuse_norm_relu = pd()->fuse_norm_relu();
 
-    assert(mkldnn_thr_syncable());
-    parallel(0, [&](const int ithr, const int nthr) {
-        dim_t N_s = 0, N_e = 0, C_s = 0, C_e = 0;
-        balance211(N, nthr, ithr, N_s, N_e);
-        balance211(C, nthr, ithr, C_s, C_e);
+    /* Note: potential seg-fault from incorrectly compiled vectorized-loop.
+     * Explicit tail-processing fixes this issue. */
+    const dim_t c_blk = mayiuse(avx512_common) ? 16 : 8;
+    const dim_t tail = C % c_blk;
+    const dim_t nb_c_blk = (size_t)C / c_blk;
+    int nthr = dnnl_get_max_threads();
 
-        acc_data_t *diff_gamma_loc = tmp_diff_ss + 2 * C + C * ithr;
-        acc_data_t *diff_beta_loc = tmp_diff_ss + 2 * C + C * (nthr + ithr);
+    parallel(nthr, [&](const int ithr, const int nthr) {
+        dim_t N_s = 0, N_e = 0;
+        balance211(N, nthr, ithr, N_s, N_e);
 
         for (dim_t c = 0; c < C; c++) {
             ws_reduce[C * ithr + c] = 0.;
@@ -321,22 +325,26 @@ void nspc_batch_normalization_bwd_t<d_type>::execute_backward(
                 }
             }
         }
+    });
 
-        mkldnn_thr_barrier();
-
-        for (dim_t c = C_s; c < C_e; c++) {
-            acc_data_t sqrt_variance
-                    = static_cast<acc_data_t>(1.0f / sqrtf(variance[c] + eps));
-            diff_gamma[c] = 0;
-            diff_beta[c] = 0;
-            for (dim_t n = 0; n < nthr; n++) {
-                diff_gamma[c] += ws_reduce[C * n + c];
-                diff_beta[c] += ws_reduce[C * nthr + C * n + c];
-            }
-            diff_gamma[c] *= sqrt_variance;
+    parallel_nd(C, [&](dim_t c) {
+        acc_data_t sqrt_variance
+                = static_cast<acc_data_t>(1.0f / sqrtf(variance[c] + eps));
+        diff_gamma[c] = 0;
+        diff_beta[c] = 0;
+        for (dim_t n = 0; n < nthr; n++) {
+            diff_gamma[c] += ws_reduce[C * n + c];
+            diff_beta[c] += ws_reduce[C * nthr + C * n + c];
         }
+        diff_gamma[c] *= sqrt_variance;
+    });
 
-        mkldnn_thr_barrier();
+    parallel(nthr, [&](const int ithr, const int nthr) {
+        dim_t N_s = 0, N_e = 0;
+        balance211(N, nthr, ithr, N_s, N_e);
+
+        acc_data_t *diff_gamma_loc = tmp_diff_ss + 2 * C + C * ithr;
+        acc_data_t *diff_beta_loc = tmp_diff_ss + 2 * C + C * (nthr + ithr);
 
         for (dim_t c = 0; c < C; c++) {
             diff_gamma_loc[c] = diff_gamma[c];
@@ -373,10 +381,11 @@ void nspc_batch_normalization_bwd_t<d_type>::execute_backward(
                             diff_dst + s_off);
                     _src = reinterpret_cast<const acc_data_t *>(src + s_off);
                 }
+
 #if SAFE_TO_USE_OMP_SIMD
-                PRAGMA_OMP_SIMD()
+                PRAGMA_OMP_SIMD(simdlen(16))
 #endif
-                for (dim_t c = 0; c < C; c++) {
+                for (dim_t c = 0; c < nb_c_blk * c_blk; c++) {
                     const size_t c_off = s_off + c;
                     acc_data_t gamma = use_scaleshift ? scaleshift[c] : 1;
                     acc_data_t sqrt_variance = static_cast<acc_data_t>(
@@ -394,6 +403,29 @@ void nspc_batch_normalization_bwd_t<d_type>::execute_backward(
                     v_diff_src *= gamma * sqrt_variance;
                     _diff_src[c] = v_diff_src;
                 }
+                for (dim_t c = 0; c < tail; c++) {
+                    const size_t c_off = s_off + nb_c_blk * c_blk + c;
+                    acc_data_t gamma = use_scaleshift
+                            ? scaleshift[nb_c_blk * c_blk + c]
+                            : 1;
+                    acc_data_t sqrt_variance = static_cast<acc_data_t>(
+                            1.0f / sqrtf(variance[nb_c_blk * c_blk + c] + eps));
+                    acc_data_t v_diff_src;
+                    if (fuse_norm_relu && !ws[c_off])
+                        v_diff_src = 0;
+                    else
+                        v_diff_src = _diff_dst[nb_c_blk * c_blk + c];
+                    if (calculate_diff_stats) {
+                        v_diff_src -= diff_beta_loc[nb_c_blk * c_blk + c]
+                                        / (SP * N)
+                                + (_src[nb_c_blk * c_blk + c]
+                                          - mean[nb_c_blk * c_blk + c])
+                                        * diff_gamma_loc[nb_c_blk * c_blk + c]
+                                        * sqrt_variance / (SP * N);
+                    }
+                    v_diff_src *= gamma * sqrt_variance;
+                    _diff_src[nb_c_blk * c_blk + c] = v_diff_src;
+                }
                 if (d_type == bf16) {
                     // convert diff_src from f32 to b16
                     cvt_float_to_bfloat16(
@@ -406,8 +438,8 @@ void nspc_batch_normalization_bwd_t<d_type>::execute_backward(
 
 template struct nspc_batch_normalization_bwd_t<f32>;
 template struct nspc_batch_normalization_bwd_t<bf16>;
-}
-}
-}
+} // namespace cpu
+} // namespace impl
+} // namespace dnnl
 
-// vim: et ts=4 sw=4 cindent cino^=l0,\:0,N-s
+// vim: et ts=4 sw=4 cindent cino+=l0,\:4,N-s
