@@ -15,13 +15,13 @@
 *******************************************************************************/
 
 #include "common/c_types_map.hpp"
+#include "common/dnnl_traits.hpp"
 #include "common/float16.hpp"
-#include "common/mkldnn_traits.hpp"
 #include "common/type_helpers.hpp"
 
 #include "ocl/jit_gen9_gemm.hpp"
 
-namespace mkldnn {
+namespace dnnl {
 namespace impl {
 namespace ocl {
 
@@ -65,76 +65,78 @@ static_assert(sizeof(plan_element_t) == 8,
         "Plan element structure has been padded by the compiler.");
 
 template <data_type_t a_type, data_type_t b_type, data_type_t c_type>
-status_t jit_gen9_gemm_t<a_type, b_type, c_type>::launch_beta(stream_t *s,
-        int64_t m, int64_t n, c_t alpha, const memory_storage_t &a,
-        int64_t offset_a, int64_t lda) const {
+status_t jit_gen9_gemm_t<a_type, b_type, c_type>::launch_beta(
+        compute::compute_stream_t *compute_stream, int64_t m, int64_t n,
+        c_t alpha, const memory_storage_t &a, int64_t offset_a,
+        int64_t lda) const {
     assert(beta_kernel_);
 
-    beta_kernel_.set_arg(0, m);
-    beta_kernel_.set_arg(1, n);
-    beta_kernel_.set_arg(2, alpha);
-    beta_kernel_.set_arg(3, a);
-    beta_kernel_.set_arg(4, offset_a);
-    beta_kernel_.set_arg(5, lda);
+    compute::kernel_arg_list_t arg_list;
+    arg_list.set(0, m);
+    arg_list.set(1, n);
+    arg_list.set(2, alpha);
+    arg_list.set(3, a);
+    arg_list.set(4, offset_a);
+    arg_list.set(5, lda);
 
-    size_t gws[3] = { 1, size_t(n), 1 };
-    size_t lws[3] = { 1, 1, 1 };
-    auto nd_range = cl_nd_range_t(gws, lws);
+    size_t gws[3] = {1, size_t(n), 1};
+    size_t lws[3] = {1, 1, 1};
+    auto nd_range = compute::nd_range_t(gws, lws);
 
-    auto &executor = *(utils::downcast<cl_stream_t *>(s)->cl_executor());
-
-    return executor.parallel_for(nd_range, beta_kernel_);
+    return compute_stream->parallel_for(nd_range, beta_kernel_, arg_list);
 }
 
 template <data_type_t a_type, data_type_t b_type, data_type_t c_type>
-status_t jit_gen9_gemm_t<a_type, b_type, c_type>::launch_copy(stream_t *s,
-        int64_t x, int64_t y, const memory_storage_t &a, int64_t offset_a,
-        int64_t lda, c_t alpha, const memory_storage_t &b, int64_t offset_b,
-        bool outer, bool trans) const {
+status_t jit_gen9_gemm_t<a_type, b_type, c_type>::launch_copy(
+        compute::compute_stream_t *compute_stream, int64_t x, int64_t y,
+        const memory_storage_t &a, int64_t offset_a, int64_t lda, c_t alpha,
+        const memory_storage_t &b, int64_t offset_b, bool outer,
+        bool trans) const {
     auto &kernel = copy_kernel_[outer][trans];
 
     assert(kernel);
-    kernel.set_arg(0, x);
-    kernel.set_arg(1, y);
-    kernel.set_arg(2, a);
-    kernel.set_arg(3, offset_a);
-    kernel.set_arg(4, lda);
-    kernel.set_arg(5, alpha);
-    kernel.set_arg(6, b);
-    kernel.set_arg(7, offset_b);
+    compute::kernel_arg_list_t arg_list;
+    arg_list.set(0, x);
+    arg_list.set(1, y);
+    arg_list.set(2, a);
+    arg_list.set(3, offset_a);
+    arg_list.set(4, lda);
+    arg_list.set(5, alpha);
+    arg_list.set(6, b);
+    arg_list.set(7, offset_b);
 
     int unroll_m, unroll_n;
     jit_gen9_gemm_copy_kernel<c_type>::get_unrolls(unroll_m, unroll_n);
 
     auto unroll = outer ? unroll_n : unroll_m;
 
-    size_t gws[3] = { size_t(x), size_t((y + unroll - 1) / unroll), 1 };
-    size_t lws[3] = { 1, 1, 1 };
+    size_t gws[3] = {size_t(x), size_t((y + unroll - 1) / unroll), 1};
+    size_t lws[3] = {1, 1, 1};
 
-    auto nd_range = cl_nd_range_t(gws, lws);
+    auto nd_range = compute::nd_range_t(gws, lws);
 
-    auto &executor = *(utils::downcast<cl_stream_t *>(s)->cl_executor());
-
-    return executor.parallel_for(nd_range, kernel);
+    return compute_stream->parallel_for(nd_range, kernel, arg_list);
 }
 
 template <data_type_t a_type, data_type_t b_type, data_type_t c_type>
-status_t jit_gen9_gemm_t<a_type, b_type, c_type>::launch_compute(stream_t *s,
-        int64_t m, int64_t n, int64_t k, const memory_storage_t &base,
-        int32_t offset_a, int32_t offset_b, const memory_storage_t &c,
-        int64_t offset_c, int64_t ldc, bool beta0) const {
+status_t jit_gen9_gemm_t<a_type, b_type, c_type>::launch_compute(
+        compute::compute_stream_t *compute_stream, int64_t m, int64_t n,
+        int64_t k, const memory_storage_t &base, int32_t offset_a,
+        int32_t offset_b, const memory_storage_t &c, int64_t offset_c,
+        int64_t ldc, bool beta0) const {
     auto &kernel = compute_kernel_[beta0];
 
     assert(kernel);
-    kernel.set_arg(0, m);
-    kernel.set_arg(1, n);
-    kernel.set_arg(2, k);
-    kernel.set_arg(3, base);
-    kernel.set_arg(4, offset_a);
-    kernel.set_arg(5, offset_b);
-    kernel.set_arg(6, c);
-    kernel.set_arg(7, offset_c);
-    kernel.set_arg(8, ldc);
+    compute::kernel_arg_list_t arg_list;
+    arg_list.set(0, m);
+    arg_list.set(1, n);
+    arg_list.set(2, k);
+    arg_list.set(3, base);
+    arg_list.set(4, offset_a);
+    arg_list.set(5, offset_b);
+    arg_list.set(6, c);
+    arg_list.set(7, offset_c);
+    arg_list.set(8, ldc);
 
     int unroll_m, unroll_n;
     jit_gen9_gemm_compute_kernel<c_type>::get_unrolls(unroll_m, unroll_n);
@@ -146,50 +148,48 @@ status_t jit_gen9_gemm_t<a_type, b_type, c_type>::launch_compute(stream_t *s,
     while (nthreads_y % lws_y)
         lws_y--;
 
-    size_t gws[3] = { size_t(nthreads_x) * 8, size_t(nthreads_y), 1 };
-    size_t lws[3] = { 8, size_t(lws_y), 1 };
+    size_t gws[3] = {size_t(nthreads_x) * 8, size_t(nthreads_y), 1};
+    size_t lws[3] = {8, size_t(lws_y), 1};
 
-    if (c_type == data_type::f16)
-        lws[1] = 1;
+    if (c_type == data_type::f16) lws[1] = 1;
 
-    auto nd_range = cl_nd_range_t(gws, lws);
+    auto nd_range = compute::nd_range_t(gws, lws);
 
-    auto &executor = *(utils::downcast<cl_stream_t *>(s)->cl_executor());
-
-    return executor.parallel_for(nd_range, kernel);
+    return compute_stream->parallel_for(nd_range, kernel, arg_list);
 }
 
 template <data_type_t a_type, data_type_t b_type, data_type_t c_type>
-status_t jit_gen9_gemm_t<a_type, b_type, c_type>::launch_nocopy(stream_t *s,
-        const memory_storage_t &a, const memory_storage_t &b,
-        const memory_storage_t &c, int64_t offset_a, int64_t offset_b,
-        int64_t offset_c, int32_t lda, int32_t ldb, int32_t ldc, int32_t m,
-        int32_t n, int32_t k, c_t alpha, c_t beta, int last_k_block,
-        c_t eltwise_alpha, c_t eltwise_beta) const {
+status_t jit_gen9_gemm_t<a_type, b_type, c_type>::launch_nocopy(
+        compute::compute_stream_t *compute_stream, const memory_storage_t &a,
+        const memory_storage_t &b, const memory_storage_t &c, int64_t offset_a,
+        int64_t offset_b, int64_t offset_c, int32_t lda, int32_t ldb,
+        int32_t ldc, int32_t m, int32_t n, int32_t k, c_t alpha, c_t beta,
+        int last_k_block, c_t eltwise_alpha, c_t eltwise_beta) const {
 
     auto &kernel = nocopy_kernel_;
 
     assert(kernel);
-    kernel.set_arg(0, a);
-    kernel.set_arg(1, b);
-    kernel.set_arg(2, c);
-    kernel.set_arg(3, offset_a);
-    kernel.set_arg(4, offset_b);
-    kernel.set_arg(5, offset_c);
-    kernel.set_arg(6, lda);
-    kernel.set_arg(7, ldb);
-    kernel.set_arg(8, ldc);
-    kernel.set_arg(9, m);
-    kernel.set_arg(10, n);
-    kernel.set_arg(11, k);
-    kernel.set_arg(12, alpha);
-    kernel.set_arg(13, beta);
-    kernel.set_arg(14, last_k_block);
-    kernel.set_arg(15, eltwise_alpha);
-    kernel.set_arg(16, eltwise_beta);
+    compute::kernel_arg_list_t arg_list;
+    arg_list.set(0, a);
+    arg_list.set(1, b);
+    arg_list.set(2, c);
+    arg_list.set(3, offset_a);
+    arg_list.set(4, offset_b);
+    arg_list.set(5, offset_c);
+    arg_list.set(6, lda);
+    arg_list.set(7, ldb);
+    arg_list.set(8, ldc);
+    arg_list.set(9, m);
+    arg_list.set(10, n);
+    arg_list.set(11, k);
+    arg_list.set(12, alpha);
+    arg_list.set(13, beta);
+    arg_list.set(14, last_k_block);
+    arg_list.set(15, eltwise_alpha);
+    arg_list.set(16, eltwise_beta);
 
-    bool transa = (pd()->desc()->transa == mkldnn_trans);
-    bool transb = (pd()->desc()->transb == mkldnn_trans);
+    bool transa = (pd()->desc()->transa == dnnl_trans);
+    bool transb = (pd()->desc()->transb == dnnl_trans);
 
     int unroll_m, unroll_n;
 
@@ -210,20 +210,17 @@ status_t jit_gen9_gemm_t<a_type, b_type, c_type>::launch_nocopy(stream_t *s,
 #endif
 
     static constexpr size_t subgroup_size = 16;
-    size_t gws[3] = { nthreads_x * subgroup_size, nthreads_y, 1 };
-    size_t lws[3] = { lthreads_x * subgroup_size, lthreads_y, 1 };
+    size_t gws[3] = {nthreads_x * subgroup_size, nthreads_y, 1};
+    size_t lws[3] = {lthreads_x * subgroup_size, lthreads_y, 1};
 
-    auto nd_range = cl_nd_range_t(gws, lws);
-
-    auto &executor = *(utils::downcast<cl_stream_t *>(s)->cl_executor());
-
-    return executor.parallel_for(nd_range, kernel);
+    auto nd_range = compute::nd_range_t(gws, lws);
+    return compute_stream->parallel_for(nd_range, kernel, arg_list);
 }
 
 template <data_type_t a_type, data_type_t b_type, data_type_t c_type>
 status_t jit_gen9_gemm_t<a_type, b_type, c_type>::launch_nocopy_superkernel(
-        stream_t *s, const memory_storage_t &plan, int32_t threads,
-        const memory_storage_t &a, const memory_storage_t &b,
+        compute::compute_stream_t *compute_stream, const memory_storage_t &plan,
+        int32_t threads, const memory_storage_t &a, const memory_storage_t &b,
         const memory_storage_t &c, int64_t offset_a, int64_t offset_b,
         int64_t offset_c, int32_t lda, int32_t ldb, int32_t ldc, int32_t m,
         int32_t n, int32_t k, c_t alpha, c_t beta, int last_k_block,
@@ -232,37 +229,35 @@ status_t jit_gen9_gemm_t<a_type, b_type, c_type>::launch_nocopy_superkernel(
     auto &kernel = nocopy_superkernel_;
 
     assert(kernel);
-    kernel.set_arg(0, plan);
-    kernel.set_arg(1, threads);
-    kernel.set_arg(2, a);
-    kernel.set_arg(3, b);
-    kernel.set_arg(4, c);
-    kernel.set_arg(5, offset_a);
-    kernel.set_arg(6, offset_b);
-    kernel.set_arg(7, offset_c);
-    kernel.set_arg(8, lda);
-    kernel.set_arg(9, ldb);
-    kernel.set_arg(10, ldc);
-    kernel.set_arg(11, m);
-    kernel.set_arg(12, n);
-    kernel.set_arg(13, k);
-    kernel.set_arg(14, alpha);
-    kernel.set_arg(15, beta);
-    kernel.set_arg(16, last_k_block);
-    kernel.set_arg(17, eltwise_alpha);
-    kernel.set_arg(18, eltwise_beta);
+    compute::kernel_arg_list_t arg_list;
+    arg_list.set(0, plan);
+    arg_list.set(1, threads);
+    arg_list.set(2, a);
+    arg_list.set(3, b);
+    arg_list.set(4, c);
+    arg_list.set(5, offset_a);
+    arg_list.set(6, offset_b);
+    arg_list.set(7, offset_c);
+    arg_list.set(8, lda);
+    arg_list.set(9, ldb);
+    arg_list.set(10, ldc);
+    arg_list.set(11, m);
+    arg_list.set(12, n);
+    arg_list.set(13, k);
+    arg_list.set(14, alpha);
+    arg_list.set(15, beta);
+    arg_list.set(16, last_k_block);
+    arg_list.set(17, eltwise_alpha);
+    arg_list.set(18, eltwise_beta);
 
     size_t lthreads = nstl::min(hw_threads_, threads);
 
     static constexpr size_t subgroup_size = 16;
-    size_t lws[3] = { subgroup_size, 1, 1 };
-    size_t gws[3] = { lthreads * subgroup_size, 1, 1 };
+    size_t lws[3] = {subgroup_size, 1, 1};
+    size_t gws[3] = {lthreads * subgroup_size, 1, 1};
 
-    auto nd_range = cl_nd_range_t(gws, lws);
-
-    auto &executor = *(utils::downcast<cl_stream_t *>(s)->cl_executor());
-
-    return executor.parallel_for(nd_range, kernel);
+    auto nd_range = compute::nd_range_t(gws, lws);
+    return compute_stream->parallel_for(nd_range, kernel, arg_list);
 }
 
 template <data_type_t a_type, data_type_t b_type, data_type_t c_type>
@@ -270,8 +265,8 @@ size_t jit_gen9_gemm_t<a_type, b_type, c_type>::max_plan_size() const {
 
     auto m = pd()->desc()->m;
     auto n = pd()->desc()->n;
-    bool transa = (pd()->desc()->transa == mkldnn_trans);
-    bool transb = (pd()->desc()->transb == mkldnn_trans);
+    bool transa = (pd()->desc()->transa == dnnl_trans);
+    bool transb = (pd()->desc()->transb == dnnl_trans);
 
     int unroll_m[2], unroll_n;
     jit_gen9_gemm_nocopy_superkernel<c_type>::get_unrolls(
@@ -296,6 +291,9 @@ template <data_type_t a_type, data_type_t b_type, data_type_t c_type>
 status_t jit_gen9_gemm_t<a_type, b_type, c_type>::execute_standard(
         const exec_ctx_t &ctx) const {
 
+    auto *compute_stream
+            = utils::downcast<compute::compute_stream_t *>(ctx.stream());
+
     using a_t = typename prec_traits<a_type>::type;
     using b_t = typename prec_traits<b_type>::type;
     using c_t = typename prec_traits<c_type>::type;
@@ -304,8 +302,8 @@ status_t jit_gen9_gemm_t<a_type, b_type, c_type>::execute_standard(
     auto n = pd()->desc()->n;
     auto k = pd()->desc()->k;
 
-    bool transa = (pd()->desc()->transa == mkldnn_trans);
-    bool transb = (pd()->desc()->transb == mkldnn_trans);
+    bool transa = (pd()->desc()->transa == dnnl_trans);
+    bool transb = (pd()->desc()->transb == dnnl_trans);
 
     auto lda = pd()->desc()->lda;
     auto ldb = pd()->desc()->ldb;
@@ -322,9 +320,9 @@ status_t jit_gen9_gemm_t<a_type, b_type, c_type>::execute_standard(
     beta_native = beta;
     one_native = 1.0f;
 
-    auto &a = CTX_IN_STORAGE(MKLDNN_ARG_SRC_0);
-    auto &b = CTX_IN_STORAGE(MKLDNN_ARG_SRC_1);
-    auto &c = CTX_OUT_STORAGE(MKLDNN_ARG_DST);
+    auto &a = CTX_IN_STORAGE(DNNL_ARG_SRC_0);
+    auto &b = CTX_IN_STORAGE(DNNL_ARG_SRC_1);
+    auto &c = CTX_OUT_STORAGE(DNNL_ARG_DST);
 
     size_t off_a0 = a.get_offset() / sizeof(a_t) + pd()->dyn_offset_a;
     size_t off_b0 = b.get_offset() / sizeof(b_t) + pd()->dyn_offset_b;
@@ -332,7 +330,7 @@ status_t jit_gen9_gemm_t<a_type, b_type, c_type>::execute_standard(
 
     bool nocopy = (gemm_type_ == type::no_copy)
             || (gemm_type_ == type::no_copy_if_even_off && !(off_a0 & 1)
-                       && !(off_b0 & 1));
+                    && !(off_b0 & 1));
 
     status_t status;
     constexpr int64_t align = 0x1000;
@@ -348,9 +346,8 @@ status_t jit_gen9_gemm_t<a_type, b_type, c_type>::execute_standard(
     }
 
     if (!nocopy && beta != 0. && beta != 1.) {
-        status = launch_beta(ctx.stream(), m, n, beta_native, c, off_c0, ldc);
-        if (status)
-            return status;
+        status = launch_beta(compute_stream, m, n, beta_native, c, off_c0, ldc);
+        if (status) return status;
     }
 
     int64_t off_b_packed = 0;
@@ -360,57 +357,51 @@ status_t jit_gen9_gemm_t<a_type, b_type, c_type>::execute_standard(
     for (int64_t Bk = 0; Bk < k; Bk += block_k) {
         int64_t size_k = k - Bk;
         bool last_k_block = (size_k <= block_k);
-        if (!last_k_block)
-            size_k = block_k;
+        if (!last_k_block) size_k = block_k;
 
         for (int64_t Bm = 0; Bm < m; Bm += block_m) {
             int64_t size_m = m - Bm;
-            if (size_m > block_m)
-                size_m = block_m;
+            if (size_m > block_m) size_m = block_m;
 
             auto off_a_src
                     = off_a0 + (!transa ? (Bm + Bk * lda) : (Bk + Bm * lda));
 
             if (!nocopy) {
-                status = launch_copy(ctx.stream(), size_k, size_m, a, off_a_src,
-                        lda, alpha_native, *temp_buf_, off_a_packed, false,
-                        !transa);
-                if (status)
-                    return status;
+                status = launch_copy(compute_stream, size_k, size_m, a,
+                        off_a_src, lda, alpha_native, *temp_buf_, off_a_packed,
+                        false, !transa);
+                if (status) return status;
             }
 
             for (int64_t Bn = 0; Bn < n; Bn += block_n) {
                 int64_t size_n = n - Bn;
-                if (size_n > block_n)
-                    size_n = block_n;
+                if (size_n > block_n) size_n = block_n;
 
                 auto off_b_src = off_b0
                         + (!transb ? (Bk + Bn * ldb) : (Bn + Bk * ldb));
 
                 if (!nocopy && ((Bn == 0) || (n > block_n))) {
-                    status = launch_copy(ctx.stream(), size_k, size_n, b,
+                    status = launch_copy(compute_stream, size_k, size_n, b,
                             off_b_src, ldb, one_native, *temp_buf_,
                             off_b_packed, true, transb);
-                    if (status)
-                        return status;
+                    if (status) return status;
                 }
 
                 auto off_c = off_c0 + Bm + Bn * ldc;
 
                 if (nocopy) {
                     float eff_beta = (Bk == 0) ? beta : 1.0f;
-                    status = launch_nocopy(ctx.stream(), a, b, c, off_a_src,
+                    status = launch_nocopy(compute_stream, a, b, c, off_a_src,
                             off_b_src, off_c, lda, ldb, ldc, size_m, size_n,
                             size_k, alpha, eff_beta, (int)last_k_block,
                             eltwise_alpha, eltwise_beta);
                 } else {
                     bool beta0 = (beta == 0) && (Bk == 0);
-                    status = launch_compute(ctx.stream(), size_m, size_n,
+                    status = launch_compute(compute_stream, size_m, size_n,
                             size_k, *temp_buf_, off_a_packed, off_b_packed, c,
                             off_c, ldc, beta0);
                 }
-                if (status)
-                    return status;
+                if (status) return status;
             }
         }
     }
@@ -422,6 +413,9 @@ template <data_type_t a_type, data_type_t b_type, data_type_t c_type>
 status_t jit_gen9_gemm_t<a_type, b_type, c_type>::execute_superkernel(
         const exec_ctx_t &ctx) const {
 
+    auto *compute_stream
+            = utils::downcast<compute::compute_stream_t *>(ctx.stream());
+
     using a_t = typename prec_traits<a_type>::type;
     using b_t = typename prec_traits<b_type>::type;
     using c_t = typename prec_traits<c_type>::type;
@@ -430,8 +424,8 @@ status_t jit_gen9_gemm_t<a_type, b_type, c_type>::execute_superkernel(
     auto n = pd()->desc()->n;
     auto k = pd()->desc()->k;
 
-    bool transa = (pd()->desc()->transa == mkldnn_trans);
-    bool transb = (pd()->desc()->transb == mkldnn_trans);
+    bool transa = (pd()->desc()->transa == dnnl_trans);
+    bool transb = (pd()->desc()->transb == dnnl_trans);
 
     auto lda = pd()->desc()->lda;
     auto ldb = pd()->desc()->ldb;
@@ -443,9 +437,9 @@ status_t jit_gen9_gemm_t<a_type, b_type, c_type>::execute_superkernel(
     auto eltwise_alpha = pd()->eltwise_alpha();
     auto eltwise_beta = pd()->eltwise_beta();
 
-    auto &a = CTX_IN_STORAGE(MKLDNN_ARG_SRC_0);
-    auto &b = CTX_IN_STORAGE(MKLDNN_ARG_SRC_1);
-    auto &c = CTX_OUT_STORAGE(MKLDNN_ARG_DST);
+    auto &a = CTX_IN_STORAGE(DNNL_ARG_SRC_0);
+    auto &b = CTX_IN_STORAGE(DNNL_ARG_SRC_1);
+    auto &c = CTX_OUT_STORAGE(DNNL_ARG_DST);
 
     size_t off_a = a.get_offset() / sizeof(a_t) + pd()->dyn_offset_a;
     size_t off_b = b.get_offset() / sizeof(b_t) + pd()->dyn_offset_b;
@@ -466,10 +460,8 @@ status_t jit_gen9_gemm_t<a_type, b_type, c_type>::execute_superkernel(
     };
 
     while (km_large >= 0) {
-        auto km_small
-                = utils::div_up(m - (km_large * unroll_m[0]), unroll_m[1]);
-        if (km_small < 0)
-            km_small = 0;
+        int km_small = utils::div_up(m - (km_large * unroll_m[0]), unroll_m[1]);
+        km_small = nstl::max(0, km_small);
 
         auto threads = (km_large + km_small) * kn;
         auto ldispatch = threads % hw_threads_;
@@ -489,13 +481,14 @@ status_t jit_gen9_gemm_t<a_type, b_type, c_type>::execute_superkernel(
     km_large = best_km_large;
 
     int km_small = utils::div_up(m - (km_large * unroll_m[0]), unroll_m[1]);
+    km_small = nstl::max(0, km_small);
+
     km = km_small + km_large;
 
     auto n_block_target = nstl::max<int>(1, 128 / unroll_n);
     auto columns = utils::div_up(kn, n_block_target);
     auto kn_left = (n_block_target - kn) % n_block_target;
-    if (kn_left < 0)
-        kn_left += n_block_target;
+    if (kn_left < 0) kn_left += n_block_target;
     auto spread = nstl::min(kn_left, columns);
 
     int bn0, bn1, columns_small;
@@ -512,8 +505,7 @@ status_t jit_gen9_gemm_t<a_type, b_type, c_type>::execute_superkernel(
     void *plan_void;
     temp_buf_->map_data(&plan_void);
 
-    if (!plan_void)
-        return status::runtime_error;
+    if (!plan_void) return status::runtime_error;
 
     auto plan = (plan_element_t *)plan_void;
 
@@ -543,8 +535,8 @@ status_t jit_gen9_gemm_t<a_type, b_type, c_type>::execute_superkernel(
     int32_t threads = km * kn;
     bool last_k_block = true;
 
-    return launch_nocopy_superkernel(ctx.stream(), *temp_buf_, threads, a, b, c,
-            off_a, off_b, off_c, lda, ldb, ldc, m, n, k, alpha, beta,
+    return launch_nocopy_superkernel(compute_stream, *temp_buf_, threads, a, b,
+            c, off_a, off_b, off_c, lda, ldb, ldc, m, n, k, alpha, beta,
             (int)last_k_block, eltwise_alpha, eltwise_beta);
 }
 
@@ -555,6 +547,6 @@ template struct jit_gen9_gemm_t<f32>;
 
 } // namespace ocl
 } // namespace impl
-} // namespace mkldnn
+} // namespace dnnl
 
-// vim: et ts=4 sw=4 cindent cino^=l0,\:0,N-s
+// vim: et ts=4 sw=4 cindent cino+=l0,\:4,N-s
