@@ -18,25 +18,26 @@
 #define JIT_SIMPLE_SUM_KERNEL_HPP
 
 #include "common/c_types_map.hpp"
+#include "compute/compute.hpp"
 #include "ocl/jit_primitive_conf.hpp"
 
-namespace mkldnn {
+namespace dnnl {
 namespace impl {
 namespace ocl {
 
 struct jit_simple_sum_kernel {
 
-    jit_simple_sum_kernel(jit_simple_sum_conf_t ajss) : jss(ajss){};
+    jit_simple_sum_kernel(jit_simple_sum_conf_t ajss) : jss(ajss) {};
 
-    ~jit_simple_sum_kernel(){};
+    ~jit_simple_sum_kernel() {};
 
     static status_t init_conf(
             jit_simple_sum_conf_t &jss, const memory_desc_t *data_d) {
         return status::success;
     };
 
-    static status_t init_const_def(
-            ocl_jit_t &jit, const jit_simple_sum_conf_t &jss) {
+    static status_t init_const_def(compute::kernel_ctx_t &kernel_ctx,
+            const jit_simple_sum_conf_t &jss) {
         return status::success;
     }
 
@@ -45,6 +46,6 @@ struct jit_simple_sum_kernel {
 
 } // namespace ocl
 } // namespace impl
-} // namespace mkldnn
+} // namespace dnnl
 
 #endif
