@@ -21,8 +21,9 @@
 #include "common/sum_pd.hpp"
 #include "common/type_helpers.hpp"
 #include "common/utils.hpp"
+#include "ocl/ocl_engine.hpp"
 
-namespace mkldnn {
+namespace dnnl {
 namespace impl {
 namespace ocl {
 
@@ -32,6 +33,6 @@ struct ocl_sum_pd_t : public sum_pd_t {
 
 } // namespace ocl
 } // namespace impl
-} // namespace mkldnn
+} // namespace dnnl
 
 #endif
