@@ -18,18 +18,17 @@
 #define OCL_REF_DECONVOLUTION_HPP
 
 #include "common/c_types_map.hpp"
-#include "common/primitive.hpp"
 #include "common/type_helpers.hpp"
 #include "common/utils.hpp"
+#include "compute/compute.hpp"
 #include "ocl/jit_primitive_conf.hpp"
 #include "ocl/ocl_convolution_pd.hpp"
 #include "ocl/ocl_deconvolution_pd.hpp"
 #include "ocl/ocl_stream.hpp"
 
-extern const char *ref_deconv_forward_bias_kernel;
 extern const char *ref_deconv_backward_bias_kernel;
 
-namespace mkldnn {
+namespace dnnl {
 namespace impl {
 namespace ocl {
 
@@ -38,8 +37,7 @@ static status_t compute_blocked_format(
     // Computes blocking for *i*o* format from *o*i* format
     bool sanity_check_ok = true && oi_md->ndims == io_md->ndims
             && oi_md->format_kind == format_kind::blocked;
-    if (!sanity_check_ok)
-        return status::invalid_arguments;
+    if (!sanity_check_ok) return status::invalid_arguments;
 
     const blocking_desc_t &oi_blk = oi_md->format_desc.blocking;
     blocking_desc_t io_blk = io_md->format_desc.blocking;
@@ -71,28 +69,26 @@ static status_t conv_descr_create(
     memory_desc_t c_weights_d;
 
     switch (dd->prop_kind) {
-    case forward:
-    case forward_inference:
-        prop_kind = backward_data;
-        src_md = &dd->dst_desc;
-        dst_md = &dd->src_desc;
-        d_weights_d = &dd->weights_desc;
-        break;
-    case backward_data:
-        prop_kind = forward_training;
-        src_md = &dd->diff_dst_desc;
-        dst_md = &dd->diff_src_desc;
-        d_weights_d = &dd->weights_desc;
-        break;
-    case backward_weights:
-        prop_kind = dd->prop_kind;
-        src_md = &dd->diff_dst_desc;
-        dst_md = &dd->src_desc;
-        d_weights_d = &dd->diff_weights_desc;
-        break;
-    default:
-        assert(!"unknown prop kind");
-        return status::invalid_arguments;
+        case forward:
+        case forward_inference:
+            prop_kind = backward_data;
+            src_md = &dd->dst_desc;
+            dst_md = &dd->src_desc;
+            d_weights_d = &dd->weights_desc;
+            break;
+        case backward_data:
+            prop_kind = forward_training;
+            src_md = &dd->diff_dst_desc;
+            dst_md = &dd->diff_src_desc;
+            d_weights_d = &dd->weights_desc;
+            break;
+        case backward_weights:
+            prop_kind = dd->prop_kind;
+            src_md = &dd->diff_dst_desc;
+            dst_md = &dd->src_desc;
+            d_weights_d = &dd->diff_weights_desc;
+            break;
+        default: assert(!"unknown prop kind"); return status::invalid_arguments;
     }
 
     const bool with_groups = d_weights_d->ndims == src_md->ndims + 1;
@@ -115,7 +111,7 @@ static status_t conv_descr_create(
             dd->strides, dd->dilates, dd->padding[0], dd->padding[1]);
 }
 
-struct ref_deconvolution_fwd_t : public primitive_t {
+struct ref_deconvolution_fwd_t : public primitive_impl_t {
     struct pd_t : public ocl_deconvolution_fwd_pd_t {
         pd_t(engine_t *engine, const deconvolution_desc_t *adesc,
                 const primitive_attr_t *attr,
@@ -128,7 +124,8 @@ struct ref_deconvolution_fwd_t : public primitive_t {
             , conv_pd_(other.conv_pd_->clone()) {}
 
         pd_t &operator=(const pd_t &other) {
-            MKLDNN_SHORT_CIRCUIT_SELF_ASSIGN(other);
+            DNNL_SHORT_CIRCUIT_SELF_ASSIGN(other);
+            ocl_deconvolution_fwd_pd_t::operator=(other);
             delete conv_pd_;
             conv_pd_ = other.conv_pd_->clone();
             return *this;
@@ -141,7 +138,7 @@ struct ref_deconvolution_fwd_t : public primitive_t {
         status_t init_convolution() {
             convolution_desc_t cd;
             CHECK(conv_descr_create(desc(), &cd));
-            status_t status = mkldnn_primitive_desc_create(
+            status_t status = dnnl_primitive_desc_create(
                     &conv_pd_, (op_desc_t *)&cd, &attr_, engine_, nullptr);
             return status;
         }
@@ -153,13 +150,14 @@ struct ref_deconvolution_fwd_t : public primitive_t {
                     && desc()->alg_kind == alg_kind::deconvolution_direct
                     && attr()->post_ops_.has_default_values()
                     && (utils::everyone_is(data_type::f32,
-                            desc()->src_desc.data_type,
-                            desc()->weights_desc.data_type,
-                            desc()->dst_desc.data_type)
-                        || utils::everyone_is(data_type::f16,
-                            desc()->src_desc.data_type,
-                            desc()->weights_desc.data_type,
-                            desc()->dst_desc.data_type));
+                                desc()->src_desc.data_type,
+                                desc()->weights_desc.data_type,
+                                desc()->dst_desc.data_type)
+                            || utils::everyone_is(data_type::f16,
+                                    desc()->src_desc.data_type,
+                                    desc()->weights_desc.data_type,
+                                    desc()->dst_desc.data_type)
+                            || desc()->dst_desc.data_type == data_type::u8);
             if (ok) {
                 CHECK(init_convolution());
                 if (weights_md_.format_kind == format_kind::any) {
@@ -189,38 +187,21 @@ struct ref_deconvolution_fwd_t : public primitive_t {
 
     typedef typename prec_traits<data_type::f32>::type data_t;
 
-    ref_deconvolution_fwd_t(const pd_t *apd) : primitive_t(apd) {}
+    ref_deconvolution_fwd_t(const pd_t *apd) : primitive_impl_t(apd) {}
     ~ref_deconvolution_fwd_t() { delete conv_p_; }
 
     virtual status_t execute(const exec_ctx_t &ctx) const override {
         const auto &args = ctx.args();
         exec_args_t conv_args;
-        conv_args[MKLDNN_ARG_DIFF_DST] = args.at(MKLDNN_ARG_SRC);
-        conv_args[MKLDNN_ARG_WEIGHTS] = args.at(MKLDNN_ARG_WEIGHTS);
+        conv_args[DNNL_ARG_DIFF_DST] = args.at(DNNL_ARG_SRC);
+        conv_args[DNNL_ARG_WEIGHTS] = args.at(DNNL_ARG_WEIGHTS);
+        conv_args[DNNL_ARG_DIFF_SRC] = args.at(DNNL_ARG_DST);
         if (pd()->with_bias())
-            conv_args[MKLDNN_ARG_BIAS] = args.at(MKLDNN_ARG_BIAS);
-        conv_args[MKLDNN_ARG_DIFF_SRC] = args.at(MKLDNN_ARG_DST);
-        const exec_ctx_t conv_ctx(ctx.stream(), std::move(conv_args));
+            conv_args[DNNL_ARG_BIAS] = args.at(DNNL_ARG_BIAS);
+        exec_ctx_t conv_ctx(ctx.stream(), std::move(conv_args));
 
         // Executing the convolution kernel
         status_t status = conv_p_->execute(conv_ctx);
-        if (status != status::success)
-            return status;
-
-        if (pd()->with_bias()) {
-            // Calling the bias kernel if bias=1
-            auto &bias = CTX_IN_STORAGE(MKLDNN_ARG_BIAS);
-            auto &dst = CTX_OUT_STORAGE(MKLDNN_ARG_DST);
-
-            bias_kernel.set_arg(0, dst);
-            bias_kernel.set_arg(1, bias);
-
-            auto &executor = *(utils::downcast<cl_stream_t *>(ctx.stream())
-                                       ->cl_executor());
-            // Setting up global work-space to {OC*G, 1, 1}
-            auto nd_range = cl_nd_range_t({ gws[0], gws[1], gws[2] });
-            status = executor.parallel_for(nd_range, bias_kernel);
-        }
         return status;
     }
 
@@ -228,45 +209,13 @@ struct ref_deconvolution_fwd_t : public primitive_t {
         // Creating convolution primitve
         status_t conv_status
                 = pd()->conv_pd_->create_primitive((primitive_t **)&conv_p_);
-        if (conv_status != status::success)
-            return conv_status;
-
-        // Initializing values for the deconv bias kernel
-        auto jit = ocl_jit_t(ref_deconv_forward_bias_kernel);
-        memory_desc_wrapper dst_mdw(pd()->dst_md());
-        jit.set_data_type(pd()->dst_md()->data_type);
-        jit_offsets jit_off;
-        set_offsets(dst_mdw, jit_off.dst_off);
-        def_offsets(jit_off.dst_off, jit, "DST", pd()->desc()->dst_desc.ndims);
-
-        jit.define_int("MB", pd()->MB());
-        jit.define_int("OH", pd()->OH());
-        jit.define_int("OW", pd()->OW());
-        jit.define_int("OD", pd()->OD());
-        jit.define_int("OC", pd()->OC() / pd()->G());
-        jit.define_int("NDIMS", pd()->desc()->dst_desc.ndims);
-
-        status_t kernel_status = jit.build(engine());
-        if (kernel_status != status::success)
-            return kernel_status;
-
-        bias_kernel = jit.get_kernel("ref_deconv_forward_bias");
-        if (!bias_kernel)
-            return status::runtime_error;
-
-        gws[0] = pd()->OC() * pd()->G();
-        gws[1] = 1;
-        gws[2] = 1;
-
-        return status::success;
+        return conv_status;
     }
-    const pd_t *pd() const { return (const pd_t *)primitive_t::pd(); }
+    const pd_t *pd() const { return (const pd_t *)primitive_impl_t::pd(); }
     primitive_t *conv_p_ = nullptr;
-    ocl_kernel_t bias_kernel;
-    size_t gws[3];
 };
 
-struct ref_deconvolution_bwd_data_t : public primitive_t {
+struct ref_deconvolution_bwd_data_t : public primitive_impl_t {
     struct pd_t : public ocl_deconvolution_bwd_data_pd_t {
         pd_t(engine_t *engine, const deconvolution_desc_t *adesc,
                 const primitive_attr_t *attr,
@@ -279,7 +228,8 @@ struct ref_deconvolution_bwd_data_t : public primitive_t {
             , conv_pd_(other.conv_pd_->clone()) {}
 
         pd_t &operator=(const pd_t &other) {
-            MKLDNN_SHORT_CIRCUIT_SELF_ASSIGN(other);
+            DNNL_SHORT_CIRCUIT_SELF_ASSIGN(other);
+            ocl_deconvolution_bwd_data_pd_t::operator=(other);
             delete conv_pd_;
             conv_pd_ = other.conv_pd_->clone();
             return *this;
@@ -292,7 +242,7 @@ struct ref_deconvolution_bwd_data_t : public primitive_t {
         status_t init_convolution() {
             convolution_desc_t cd;
             CHECK(conv_descr_create(desc(), &cd));
-            status_t status = mkldnn_primitive_desc_create(
+            status_t status = dnnl_primitive_desc_create(
                     &conv_pd_, (op_desc_t *)&cd, &attr_, engine_, nullptr);
             return status;
         }
@@ -333,18 +283,18 @@ struct ref_deconvolution_bwd_data_t : public primitive_t {
 
     typedef typename prec_traits<data_type::f32>::type data_t;
 
-    ref_deconvolution_bwd_data_t(const pd_t *apd) : primitive_t(apd) {}
+    ref_deconvolution_bwd_data_t(const pd_t *apd) : primitive_impl_t(apd) {}
     ~ref_deconvolution_bwd_data_t() { delete conv_p_; }
 
     virtual status_t execute(const exec_ctx_t &ctx) const override {
         const auto &args = ctx.args();
         exec_args_t conv_args;
-        conv_args[MKLDNN_ARG_SRC] = args.at(MKLDNN_ARG_DIFF_DST);
-        conv_args[MKLDNN_ARG_WEIGHTS] = args.at(MKLDNN_ARG_WEIGHTS);
-        conv_args[MKLDNN_ARG_DST] = args.at(MKLDNN_ARG_DIFF_SRC);
+        conv_args[DNNL_ARG_SRC] = args.at(DNNL_ARG_DIFF_DST);
+        conv_args[DNNL_ARG_WEIGHTS] = args.at(DNNL_ARG_WEIGHTS);
+        conv_args[DNNL_ARG_DST] = args.at(DNNL_ARG_DIFF_SRC);
         if (!types::is_zero_md(pd()->scratchpad_md()))
-            conv_args[MKLDNN_ARG_SCRATCHPAD] = args.at(MKLDNN_ARG_SCRATCHPAD);
-        const exec_ctx_t conv_ctx(ctx.stream(), std::move(conv_args));
+            conv_args[DNNL_ARG_SCRATCHPAD] = args.at(DNNL_ARG_SCRATCHPAD);
+        exec_ctx_t conv_ctx(ctx.stream(), std::move(conv_args));
 
         // Executing the convolution kernel
         status_t status = conv_p_->execute(conv_ctx);
@@ -358,11 +308,11 @@ struct ref_deconvolution_bwd_data_t : public primitive_t {
     }
 
 private:
-    const pd_t *pd() const { return (const pd_t *)primitive_t::pd(); }
+    const pd_t *pd() const { return (const pd_t *)primitive_impl_t::pd(); }
     primitive_t *conv_p_ = nullptr;
 };
 
-struct ref_deconvolution_bwd_weights_t : public primitive_t {
+struct ref_deconvolution_bwd_weights_t : public primitive_impl_t {
     struct pd_t : public ocl_deconvolution_bwd_weights_pd_t {
         pd_t(engine_t *engine, const deconvolution_desc_t *adesc,
                 const primitive_attr_t *attr,
@@ -376,7 +326,8 @@ struct ref_deconvolution_bwd_weights_t : public primitive_t {
             , conv_pd_(other.conv_pd_->clone()) {}
 
         pd_t &operator=(const pd_t &other) {
-            MKLDNN_SHORT_CIRCUIT_SELF_ASSIGN(other);
+            DNNL_SHORT_CIRCUIT_SELF_ASSIGN(other);
+            ocl_deconvolution_bwd_weights_pd_t::operator=(other);
             delete conv_pd_;
             conv_pd_ = other.conv_pd_->clone();
             return *this;
@@ -389,7 +340,7 @@ struct ref_deconvolution_bwd_weights_t : public primitive_t {
         status_t init_convolution() {
             convolution_desc_t cd;
             CHECK(conv_descr_create(desc(), &cd));
-            status_t status = mkldnn_primitive_desc_create(
+            status_t status = dnnl_primitive_desc_create(
                     &conv_pd_, (op_desc_t *)&cd, &attr_, engine_, nullptr);
             return status;
         }
@@ -434,38 +385,39 @@ struct ref_deconvolution_bwd_weights_t : public primitive_t {
 
     typedef typename prec_traits<data_type::f32>::type data_t;
 
-    ref_deconvolution_bwd_weights_t(const pd_t *apd) : primitive_t(apd) {
-        pd()->conv_pd_->create_primitive((primitive_t **)&conv_p_);
-    }
+    ref_deconvolution_bwd_weights_t(const pd_t *apd) : primitive_impl_t(apd) {}
+
     ~ref_deconvolution_bwd_weights_t() { delete conv_p_; }
 
     virtual status_t execute(const exec_ctx_t &ctx) const override {
+        auto *compute_stream
+                = utils::downcast<compute::compute_stream_t *>(ctx.stream());
+
         const auto &args = ctx.args();
         exec_args_t conv_args;
-        conv_args[MKLDNN_ARG_DIFF_DST] = args.at(MKLDNN_ARG_SRC);
-        conv_args[MKLDNN_ARG_SRC] = args.at(MKLDNN_ARG_DIFF_DST);
-        conv_args[MKLDNN_ARG_DIFF_WEIGHTS] = args.at(MKLDNN_ARG_DIFF_WEIGHTS);
+        conv_args[DNNL_ARG_DIFF_DST] = args.at(DNNL_ARG_SRC);
+        conv_args[DNNL_ARG_SRC] = args.at(DNNL_ARG_DIFF_DST);
+        conv_args[DNNL_ARG_DIFF_WEIGHTS] = args.at(DNNL_ARG_DIFF_WEIGHTS);
         if (!types::is_zero_md(pd()->scratchpad_md()))
-            conv_args[MKLDNN_ARG_SCRATCHPAD] = args.at(MKLDNN_ARG_SCRATCHPAD);
-        const exec_ctx_t conv_ctx(ctx.stream(), std::move(conv_args));
+            conv_args[DNNL_ARG_SCRATCHPAD] = args.at(DNNL_ARG_SCRATCHPAD);
+        exec_ctx_t conv_ctx(ctx.stream(), std::move(conv_args));
 
         status_t status = conv_p_->execute(conv_ctx);
-        if (status != status::success)
-            return status;
+        if (status != status::success) return status;
 
         if (pd()->with_bias()) {
             // Calling the bias kernel if bias=1
-            auto &diff_bias = CTX_OUT_STORAGE(MKLDNN_ARG_DIFF_BIAS);
-            auto &diff_dst = CTX_IN_STORAGE(MKLDNN_ARG_DIFF_DST);
+            auto &diff_bias = CTX_OUT_STORAGE(DNNL_ARG_DIFF_BIAS);
+            auto &diff_dst = CTX_IN_STORAGE(DNNL_ARG_DIFF_DST);
 
-            bias_kernel.set_arg(0, diff_dst);
-            bias_kernel.set_arg(1, diff_bias);
+            compute::kernel_arg_list_t arg_list;
+            arg_list.set(0, diff_dst);
+            arg_list.set(1, diff_bias);
 
-            auto &executor = *(utils::downcast<cl_stream_t *>(ctx.stream())
-                                       ->cl_executor());
             // Setting up global work-space to {OC*G, 1, 1}
-            auto nd_range = cl_nd_range_t({ gws[0], gws[1], gws[2] });
-            status = executor.parallel_for(nd_range, bias_kernel);
+            auto nd_range = compute::nd_range_t({gws[0], gws[1], gws[2]});
+            status = compute_stream->parallel_for(
+                    nd_range, bias_kernel, arg_list);
         }
         return status::success;
     }
@@ -474,32 +426,30 @@ struct ref_deconvolution_bwd_weights_t : public primitive_t {
         // Creating convolution primitve
         status_t conv_status
                 = pd()->conv_pd_->create_primitive((primitive_t **)&conv_p_);
-        if (conv_status != status::success)
-            return conv_status;
+        if (conv_status != status::success) return conv_status;
 
         // Initializing values for the deconv bias kernel
-        auto jit = ocl_jit_t(ref_deconv_backward_bias_kernel);
+        auto *compute_engine
+                = utils::downcast<compute::compute_engine_t *>(engine());
+        compute::kernel_ctx_t kernel_ctx;
+
         memory_desc_wrapper diff_dst_mdw(pd()->diff_dst_md());
-        jit.set_data_type(pd()->diff_dst_md()->data_type);
+        kernel_ctx.set_data_type(pd()->diff_dst_md()->data_type);
         jit_offsets jit_off;
         set_offsets(diff_dst_mdw, jit_off.dst_off);
-        def_offsets(
-                jit_off.dst_off, jit, "DST", pd()->desc()->diff_dst_desc.ndims);
+        def_offsets(jit_off.dst_off, kernel_ctx, "DST",
+                pd()->desc()->diff_dst_desc.ndims);
 
-        jit.define_int("MB", pd()->MB());
-        jit.define_int("OH", pd()->OH());
-        jit.define_int("OW", pd()->OW());
-        jit.define_int("OD", pd()->OD());
-        jit.define_int("OC", pd()->OC() / pd()->G());
-        jit.define_int("NDIMS", pd()->desc()->src_desc.ndims);
+        kernel_ctx.define_int("MB", pd()->MB());
+        kernel_ctx.define_int("OH", pd()->OH());
+        kernel_ctx.define_int("OW", pd()->OW());
+        kernel_ctx.define_int("OD", pd()->OD());
+        kernel_ctx.define_int("OC", pd()->OC() / pd()->G());
+        kernel_ctx.define_int("NDIMS", pd()->desc()->src_desc.ndims);
 
-        status_t kernel_status = jit.build(engine());
-        if (kernel_status != status::success)
-            return kernel_status;
-
-        bias_kernel = jit.get_kernel("ref_deconv_backward_bias");
-        if (!bias_kernel)
-            return status::runtime_error;
+        compute_engine->create_kernel(
+                &bias_kernel, "ref_deconv_backward_bias", kernel_ctx);
+        if (!bias_kernel) return status::runtime_error;
 
         gws[0] = pd()->OC() * pd()->G();
         gws[1] = 1;
@@ -509,14 +459,14 @@ struct ref_deconvolution_bwd_weights_t : public primitive_t {
     }
 
 private:
-    const pd_t *pd() const { return (const pd_t *)primitive_t::pd(); }
+    const pd_t *pd() const { return (const pd_t *)primitive_impl_t::pd(); }
     primitive_t *conv_p_ = nullptr;
-    ocl_kernel_t bias_kernel;
+    compute::kernel_t bias_kernel;
     size_t gws[3];
 };
 
 } // namespace ocl
 } // namespace impl
-} // namespace mkldnn
+} // namespace dnnl
 
 #endif
