@@ -15,14 +15,14 @@
 # limitations under the License.
 #===============================================================================
 
-mkldnn_root="$1"
+dnnl_root="$1"
 output="$2"
 shift 2
 
-echo -e '#include "mkldnn.h"' > "$output"
+echo -e '#include "dnnl.h"' > "$output"
 echo -e "const void *c_functions[] = {" >> "$output"
-cpp -w "${@/#/-I}" "${mkldnn_root}/include/mkldnn.h" \
-    | grep -o 'mkldnn_\w\+(' \
+cpp -w "${@/#/-I}" "${dnnl_root}/include/dnnl.h" \
+    | grep -o 'dnnl_\w\+(' \
     | sed 's/\(.*\)(/(void*)\1,/g' \
     | sort -u >> "$output"
 echo -e "NULL};\nint main() { return 0; }" >> "$output"
