@@ -14,23 +14,21 @@
 * limitations under the License.
 *******************************************************************************/
 
-#include "mkldnn_test_common.hpp"
+#include "dnnl_test_common.hpp"
 #include "gtest/gtest.h"
 
-#include "mkldnn.hpp"
+#include "dnnl.hpp"
 #include "test_convolution_backward_data_common.hpp"
 
-namespace mkldnn {
+namespace dnnl {
 
-using convolution_test = convolution_backward_data_test<float, float,
-                                                        float, float>;
+using convolution_test
+        = convolution_backward_data_test<float, float, float, float>;
 
-TEST_P(convolution_test, TestConvolution)
-{
-}
+TEST_P(convolution_test, TestConvolution) {}
 
 #define FP32
 #define DIRECTION_BACKWARD_DATA
 #include "convolution_common.h"
 
-}
+} // namespace dnnl
